summaryrefslogtreecommitdiff
path: root/svx
diff options
context:
space:
mode:
authorFrank Schönheit <fs@openoffice.org>2000-10-20 13:13:45 +0000
committerFrank Schönheit <fs@openoffice.org>2000-10-20 13:13:45 +0000
commit04a985d1c978ba1ffffcdf6411bf3dbbe9c706ec (patch)
tree80a970d9b8afb162e6a93128d91159563ce9a5f3 /svx
parent41c39df841c14c806bef49158d03c3c800ad8ed4 (diff)
migration unotools->comphelper
Diffstat (limited to 'svx')
-rw-r--r--svx/inc/fmgridif.hxx8
-rw-r--r--svx/source/fmcomp/fmgridcl.cxx68
-rw-r--r--svx/source/fmcomp/fmgridif.cxx94
-rw-r--r--svx/source/fmcomp/gridcell.cxx242
-rw-r--r--svx/source/fmcomp/gridcols.cxx14
-rw-r--r--svx/source/fmcomp/gridctrl.cxx85
-rw-r--r--svx/source/inc/fmcontr.hxx10
-rw-r--r--svx/source/inc/fmctrler.hxx16
-rw-r--r--svx/source/inc/fmexch.hxx8
-rw-r--r--svx/source/inc/fmitems.hxx8
-rw-r--r--svx/source/inc/fmpgeimp.hxx8
-rw-r--r--svx/source/inc/fmshimp.hxx18
-rw-r--r--svx/source/inc/fmsrcimp.hxx8
-rw-r--r--svx/source/inc/fmtools.hxx8
-rw-r--r--svx/source/inc/fmundo.hxx8
-rw-r--r--svx/source/inc/fmvwimp.hxx12
-rw-r--r--svx/source/inc/gridcell.hxx16
-rw-r--r--svx/source/inc/tabwin.hxx12
18 files changed, 326 insertions, 317 deletions
diff --git a/svx/inc/fmgridif.hxx b/svx/inc/fmgridif.hxx
index bc6befafac9b..805e29d5c40e 100644
--- a/svx/inc/fmgridif.hxx
+++ b/svx/inc/fmgridif.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: fmgridif.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 17:00:56 $
+ * last change: $Author: fs $ $Date: 2000-10-20 14:12:24 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -126,8 +126,8 @@
#include <toolkit/awt/vclxwindow.hxx>
#endif
-#ifndef _UTL_UNO3_HXX_
-#include <unotools/uno3.hxx>
+#ifndef _COMPHELPER_UNO3_HXX_
+#include <comphelper/uno3.hxx>
#endif
class DbGridColumn;
diff --git a/svx/source/fmcomp/fmgridcl.cxx b/svx/source/fmcomp/fmgridcl.cxx
index 166db0d2ade8..d04063bdcab8 100644
--- a/svx/source/fmcomp/fmgridcl.cxx
+++ b/svx/source/fmcomp/fmgridcl.cxx
@@ -2,9 +2,9 @@
*
* $RCSfile: fmgridcl.cxx,v $
*
- * $Revision: 1.3 $
+ * $Revision: 1.4 $
*
- * last change: $Author: fs $ $Date: 2000-09-21 12:49:03 $
+ * last change: $Author: fs $ $Date: 2000-10-20 14:13:45 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -228,14 +228,14 @@
#include <cppuhelper/extract.hxx>
#endif
-#ifndef _UTL_UNO3_DB_TOOLS_HXX_
-#include <unotools/dbtools.hxx>
+#ifndef _CONNECTIVITY_DBTOOLS_HXX_
+#include <connectivity/dbtools.hxx>
#endif
-#ifndef _UTL_PROPERTY_HXX_
-#include <unotools/property.hxx>
+#ifndef _COMPHELPER_PROPERTY_HXX_
+#include <comphelper/property.hxx>
#endif
-#ifndef _UTL_NUMBERS_HXX_
-#include <unotools/numbers.hxx>
+#ifndef _COMPHELPER_NUMBERS_HXX_
+#include <comphelper/numbers.hxx>
#endif
#ifndef _ISOLANG_HXX
#include <tools/isolang.hxx>
@@ -484,18 +484,18 @@ sal_Bool FmGridHeader::Drop( const DropEvent& rEvt )
if (xFields.is() && xFields->hasByName(aFieldName))
::cppu::extractInterface(xField, xFields->getByName(aFieldName));
- ::com::sun::star::uno::Reference< ::com::sun::star::util::XNumberFormatsSupplier > xSupplier = ::utl::getNumberFormats(xConnection, sal_True);
+ ::com::sun::star::uno::Reference< ::com::sun::star::util::XNumberFormatsSupplier > xSupplier = ::dbtools::getNumberFormats(xConnection, sal_True);
if (!xSupplier.is())
{
- ::utl::disposeComponent(xStatement);
+ ::comphelper::disposeComponent(xStatement);
return sal_False;
}
::com::sun::star::uno::Reference< ::com::sun::star::util::XNumberFormats > xNumberFormats(xSupplier->getNumberFormats());
if (!xNumberFormats.is())
{
- ::utl::disposeComponent(xStatement);
+ ::comphelper::disposeComponent(xStatement);
return sal_False;
}
@@ -511,7 +511,7 @@ sal_Bool FmGridHeader::Drop( const DropEvent& rEvt )
case ::com::sun::star::sdbc::DataType::BINARY:
case ::com::sun::star::sdbc::DataType::VARBINARY:
case ::com::sun::star::sdbc::DataType::OTHER:
- ::utl::disposeComponent(xStatement);
+ ::comphelper::disposeComponent(xStatement);
return sal_False;
}
@@ -573,8 +573,8 @@ sal_Bool FmGridHeader::Drop( const DropEvent& rEvt )
// if it's a currency field, a a "currency field" option
try
{
- if ( ::utl::hasProperty(FM_PROP_ISCURRENCY, xField)
- && ::utl::getBOOL(xField->getPropertyValue(FM_PROP_ISCURRENCY)))
+ if ( ::comphelper::hasProperty(FM_PROP_ISCURRENCY, xField)
+ && ::comphelper::getBOOL(xField->getPropertyValue(FM_PROP_ISCURRENCY)))
aPossibleTypes.Insert(SID_FM_CURRENCYFIELD, 0);
}
catch(...)
@@ -611,7 +611,7 @@ sal_Bool FmGridHeader::Drop( const DropEvent& rEvt )
if (sFieldService.len())
{
xThisRoundCol = xFactory->createColumn(sFieldService);
- if (xThisRoundCol.is() && ::utl::hasProperty(FM_PROP_STRICTFORMAT, xThisRoundCol))
+ if (xThisRoundCol.is() && ::comphelper::hasProperty(FM_PROP_STRICTFORMAT, xThisRoundCol))
xThisRoundCol->setPropertyValue(FM_PROP_STRICTFORMAT, ::com::sun::star::uno::makeAny(sal_Bool(sal_False)));
}
if (nColCount)
@@ -623,8 +623,8 @@ sal_Bool FmGridHeader::Drop( const DropEvent& rEvt )
if (!xCol.is() || (bDateNTimeCol && !xSecondCol.is()))
{
- ::utl::disposeComponent(xCol); // in case only teh creation of the second column failed
- ::utl::disposeComponent(xStatement);
+ ::comphelper::disposeComponent(xCol); // in case only teh creation of the second column failed
+ ::comphelper::disposeComponent(xStatement);
return sal_False;
}
@@ -640,7 +640,7 @@ sal_Bool FmGridHeader::Drop( const DropEvent& rEvt )
if (nPreferedType == SID_FM_NUMERICFIELD)
{
{
- ::com::sun::star::uno::Any aScaleVal(::utl::getNumberFormatDecimals(xNumberFormats, nFormatKey));
+ ::com::sun::star::uno::Any aScaleVal(::comphelper::getNumberFormatDecimals(xNumberFormats, nFormatKey));
xCol->setPropertyValue(FM_PROP_DECIMAL_ACCURACY,aScaleVal);
}
@@ -707,10 +707,10 @@ sal_Bool FmGridHeader::Drop( const DropEvent& rEvt )
::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > xForm(xFormCp->getParent(), ::com::sun::star::uno::UNO_QUERY);
if (xForm.is())
{
- if (!::utl::getString(xForm->getPropertyValue(FM_PROP_DATASOURCE)).getLength())
+ if (!::comphelper::getString(xForm->getPropertyValue(FM_PROP_DATASOURCE)).getLength())
xForm->setPropertyValue(FM_PROP_DATASOURCE, XUB2ANY(aDatabaseName));
- if (!::utl::getString(xForm->getPropertyValue(FM_PROP_COMMAND)).getLength())
+ if (!::comphelper::getString(xForm->getPropertyValue(FM_PROP_COMMAND)).getLength())
{
xForm->setPropertyValue(FM_PROP_COMMAND, XUB2ANY(aObjectName));
::com::sun::star::uno::Any aCommandType;
@@ -735,7 +735,7 @@ sal_Bool FmGridHeader::Drop( const DropEvent& rEvt )
catch(...)
{
DBG_ERROR("FmGridHeader::Drop : catched an exception while creatin' the column !");
- ::utl::disposeComponent(xStatement);
+ ::comphelper::disposeComponent(xStatement);
return sal_False;
}
return sal_True;
@@ -827,13 +827,13 @@ void FmGridHeader::PreExecuteColumnContextMenu(sal_uInt16 nColId, PopupMenu& rMe
aHidden = xCurCol->getPropertyValue(FM_PROP_HIDDEN);
DBG_ASSERT(aHidden.getValueType().getTypeClass() == ::com::sun::star::uno::TypeClass_BOOLEAN,
"FmGridHeader::PreExecuteColumnContextMenu : the property 'hidden' should be boolean !");
- if (::utl::getBOOL(aHidden))
+ if (::comphelper::getBOOL(aHidden))
{
// put the column name into the 'show col' menu
if (nHiddenCols < 16)
{ // (only the first 16 items to keep the menu rather small)
aName = xCurCol->getPropertyValue(FM_PROP_LABEL);
- pShowColsMenu->InsertItem(nHiddenCols + 1, ::utl::getString(aName), 0, nHiddenCols);
+ pShowColsMenu->InsertItem(nHiddenCols + 1, ::comphelper::getString(aName), 0, nHiddenCols);
// the ID is arbitrary, but should be unique within the whole menu
}
++nHiddenCols;
@@ -895,7 +895,7 @@ void FmGridHeader::PostExecuteColumnContextMenu(sal_uInt16 nColId, const PopupMe
::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface > xCol;
::cppu::extractInterface(xCol, xCols->getByIndex(nPos));
xCols->removeByIndex(nPos);
- ::utl::disposeComponent(xCol);
+ ::comphelper::disposeComponent(xCol);
} break;
case SID_FM_SHOW_PROPERTY_BROWSER:
{
@@ -998,7 +998,7 @@ void FmGridHeader::PostExecuteColumnContextMenu(sal_uInt16 nColId, const PopupMe
{
::cppu::extractInterface(xCurCol, xCols->getByIndex(i));
::com::sun::star::uno::Any aHidden = xCurCol->getPropertyValue(FM_PROP_HIDDEN);
- if (::utl::getBOOL(aHidden))
+ if (::comphelper::getBOOL(aHidden))
if (!--nExecutionResult)
{
xCurCol->setPropertyValue(FM_PROP_HIDDEN, ::com::sun::star::uno::makeAny((sal_Bool)sal_False));
@@ -1028,10 +1028,10 @@ void FmGridHeader::PostExecuteColumnContextMenu(sal_uInt16 nColId, const PopupMe
ConvertLanguageToIsoNames(Application::GetAppInternational().GetLanguage(), sLanguage, sCountry);
::com::sun::star::lang::Locale aAppLocale(sLanguage, sCountry, ::rtl::OUString());
- ::utl::TransferFormComponentProperties(xReplaced, xCol, aAppLocale);
+ ::dbtools::TransferFormComponentProperties(xReplaced, xCol, aAppLocale);
xCols->replaceByIndex(nPos, aNew);
- ::utl::disposeComponent(xReplaced);
+ ::comphelper::disposeComponent(xReplaced);
}
else
{
@@ -1101,7 +1101,7 @@ void FmGridControl::propertyChange(const ::com::sun::star::beans::PropertyChange
if (evt.PropertyName == FM_PROP_ISMODIFIED)
{
// modified or clean ?
- GridRowStatus eStatus = ::utl::getBOOL(evt.NewValue) ? GRS_MODIFIED : GRS_CLEAN;
+ GridRowStatus eStatus = ::comphelper::getBOOL(evt.NewValue) ? GRS_MODIFIED : GRS_CLEAN;
if (eStatus != xRow->GetStatus())
{
xRow->SetStatus(eStatus);
@@ -1564,7 +1564,7 @@ void FmGridControl::InitColumnsByModels(const ::com::sun::star::uno::Reference<
{
::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > xCol;
::cppu::extractInterface(xCol, xColumns->getByIndex(i));
- aName = (const sal_Unicode*)::utl::getString(xCol->getPropertyValue(FM_PROP_LABEL));
+ aName = (const sal_Unicode*)::comphelper::getString(xCol->getPropertyValue(FM_PROP_LABEL));
aWidth = xCol->getPropertyValue(FM_PROP_WIDTH);
sal_Int32 nWidth = 0;
@@ -1586,7 +1586,7 @@ void FmGridControl::InitColumnsByModels(const ::com::sun::star::uno::Reference<
::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > xCol;
::cppu::extractInterface(xCol, xColumns->getByIndex(i));
aHidden = xCol->getPropertyValue(FM_PROP_HIDDEN);
- if (::utl::getBOOL(aHidden))
+ if (::comphelper::getBOOL(aHidden))
HideColumn(GetColumnIdFromModelPos(i));
}
@@ -1661,19 +1661,19 @@ void FmGridControl::InitColumnsByFields(const ::com::sun::star::uno::Reference<
else
{
// Feststellen ob ReadOnly
- sal_Bool bReadOnly = ::utl::getBOOL(xField->getPropertyValue(FM_PROP_ISREADONLY));
+ sal_Bool bReadOnly = ::comphelper::getBOOL(xField->getPropertyValue(FM_PROP_ISREADONLY));
pCol->SetReadOnly(bReadOnly);
}
}
// anhand des ServiceNamens wird das Control bestimmt
::rtl::OUString sPropColumnServiceName = ::rtl::OUString::createFromAscii("ColumnServiceName");
- if (!::utl::hasProperty(sPropColumnServiceName, xCol))
+ if (!::comphelper::hasProperty(sPropColumnServiceName, xCol))
return;
pCol->setModel(xCol);
- sal_Int32 nTypeId = getColumnTypeByModelName(::utl::getString(xCol->getPropertyValue(sPropColumnServiceName)));
+ sal_Int32 nTypeId = getColumnTypeByModelName(::comphelper::getString(xCol->getPropertyValue(sPropColumnServiceName)));
pCol->CreateControl(nFieldPos, xField, nTypeId);
}
}
@@ -1741,7 +1741,7 @@ void FmGridControl::ShowColumn(sal_uInt16 nId)
for (i=0; i<nSelectedRows; ++i)
{
- nIdx = ::utl::getINT32(pBookmarks[i]);
+ nIdx = ::comphelper::getINT32(pBookmarks[i]);
if (IsEmptyRow(nIdx))
{
// leerzeile nicht loeschen
diff --git a/svx/source/fmcomp/fmgridif.cxx b/svx/source/fmcomp/fmgridif.cxx
index cf09d22b1565..bccfd3434bb7 100644
--- a/svx/source/fmcomp/fmgridif.cxx
+++ b/svx/source/fmcomp/fmgridif.cxx
@@ -2,9 +2,9 @@
*
* $RCSfile: fmgridif.cxx,v $
*
- * $Revision: 1.2 $
+ * $Revision: 1.3 $
*
- * last change: $Author: oj $ $Date: 2000-10-11 12:32:27 $
+ * last change: $Author: fs $ $Date: 2000-10-20 14:13:45 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -122,20 +122,20 @@
#include <toolkit/helper/vclunohelper.hxx>
#endif
-#ifndef _UTL_CONTAINER_HXX_
-#include <unotools/container.hxx>
+#ifndef _COMPHELPER_CONTAINER_HXX_
+#include <comphelper/container.hxx>
#endif
-#ifndef _UNOTOOLS_ENUMHELPER_HXX_
-#include <unotools/enumhelper.hxx>
+#ifndef _COMPHELPER_ENUMHELPER_HXX_
+#include <comphelper/enumhelper.hxx>
#endif
-#ifndef _UTL_PROPERTY_HXX_
-#include <unotools/property.hxx>
+#ifndef _COMPHELPER_PROPERTY_HXX_
+#include <comphelper/property.hxx>
#endif
-#ifndef _UTL_TYPES_HXX_
-#include <unotools/types.hxx>
+#ifndef _COMPHELPER_TYPES_HXX_
+#include <comphelper/types.hxx>
#endif
-#ifndef _UNOTOOLS_PROCESSFACTORY_HXX_
-#include <unotools/processfactory.hxx>
+#ifndef _COMPHELPER_PROCESSFACTORY_HXX_
+#include <comphelper/processfactory.hxx>
#endif
#ifndef _FM_IMPLEMENTATION_IDS_HXX_
@@ -409,7 +409,7 @@ FmXGridControl::~FmXGridControl()
//------------------------------------------------------------------------------
sal_Bool SAL_CALL FmXGridControl::supportsService(const ::rtl::OUString& ServiceName) throw()
{
- ::utl::StringSequence aSupported = getSupportedServiceNames();
+ ::comphelper::StringSequence aSupported = getSupportedServiceNames();
const ::rtl::OUString * pArray = aSupported.getConstArray();
for( sal_Int32 i = 0; i < aSupported.getLength(); i++ )
if( pArray[i] == ServiceName )
@@ -424,11 +424,11 @@ sal_Bool SAL_CALL FmXGridControl::supportsService(const ::rtl::OUString& Service
}
//------------------------------------------------------------------------------
-::utl::StringSequence SAL_CALL FmXGridControl::getSupportedServiceNames() throw()
+::comphelper::StringSequence SAL_CALL FmXGridControl::getSupportedServiceNames() throw()
{
static ::rtl::OUString aServName = FM_SUN_CONTROL_GRIDCONTROL;
// static ::rtl::OUString aServName(FM_SUN_CONTROL_GRIDCONTROL);
- return ::utl::StringSequence(&aServName, 1);
+ return ::comphelper::StringSequence(&aServName, 1);
}
//------------------------------------------------------------------------------
@@ -477,7 +477,7 @@ FmXGridPeer* FmXGridControl::imp_CreatePeer(Window* pParent)
{
try
{
- if (::utl::getINT16(xModelSet->getPropertyValue(FM_PROP_BORDER)))
+ if (::comphelper::getINT16(xModelSet->getPropertyValue(FM_PROP_BORDER)))
nStyle |= WB_BORDER;
}
catch(...)
@@ -586,7 +586,7 @@ void SAL_CALL FmXGridControl::createPeer(const ::com::sun::star::uno::Reference<
if (::com::sun::star::uno::Reference< ::com::sun::star::container::XIndexAccess > (xColumnsSupplier->getColumns(),::com::sun::star::uno::UNO_QUERY)->getCount())
{
// we get only a new bookmark if the resultset is not forwardonly
- if (::utl::getINT32(::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > (xForm, ::com::sun::star::uno::UNO_QUERY)->getPropertyValue(FM_PROP_RESULTSET_TYPE)) != ::com::sun::star::sdbc::ResultSetType::FORWARD_ONLY)
+ if (::comphelper::getINT32(::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > (xForm, ::com::sun::star::uno::UNO_QUERY)->getPropertyValue(FM_PROP_RESULTSET_TYPE)) != ::com::sun::star::sdbc::ResultSetType::FORWARD_ONLY)
{
// as the FmGridControl touches the data source it is connected to we have to remember the current
// cursor position (and restore afterwards)
@@ -826,7 +826,7 @@ sal_Bool SAL_CALL FmXGridControl::hasElements() throw( ::com::sun::star::uno::Ru
if (xPeer.is())
return xPeer->createEnumeration();
else
- return new ::utl::OEnumerationByIndex(this);
+ return new ::comphelper::OEnumerationByIndex(this);
}
// ::com::sun::star::container::XIndexAccess
@@ -866,10 +866,10 @@ void SAL_CALL FmXGridControl::setMode(const ::rtl::OUString& Mode) throw( ::com:
}
//------------------------------------------------------------------------------
-::utl::StringSequence SAL_CALL FmXGridControl::getSupportedModes() throw( ::com::sun::star::uno::RuntimeException )
+::comphelper::StringSequence SAL_CALL FmXGridControl::getSupportedModes() throw( ::com::sun::star::uno::RuntimeException )
{
::com::sun::star::uno::Reference< ::com::sun::star::util::XModeSelector > xPeer(mxPeer, ::com::sun::star::uno::UNO_QUERY);
- return xPeer.is() ? xPeer->getSupportedModes() : ::utl::StringSequence();
+ return xPeer.is() ? xPeer->getSupportedModes() : ::comphelper::StringSequence();
}
//------------------------------------------------------------------------------
@@ -1181,7 +1181,7 @@ void FmXGridPeer::removeModifyListener(const ::com::sun::star::uno::Reference< :
xCurrentColumn;
::cppu::extractInterface(xCurrentColumn, xColumns->getByIndex(nModelPos));
- if (!::utl::hasProperty(FM_PROP_CLASSID, xCurrentColumn))
+ if (!::comphelper::hasProperty(FM_PROP_CLASSID, xCurrentColumn))
continue;
sal_Int16 nClassId;
@@ -1264,7 +1264,7 @@ void FmXGridPeer::removeModifyListener(const ::com::sun::star::uno::Reference< :
case ::com::sun::star::uno::TypeClass_LONG : pReturnArray[i] <<= (sal_Int32)xFieldContent->getLong(); break;
case ::com::sun::star::uno::TypeClass_UNSIGNED_SHORT: pReturnArray[i] <<= (sal_uInt16)xFieldContent->getShort(); break;
case ::com::sun::star::uno::TypeClass_UNSIGNED_LONG : pReturnArray[i] <<= (sal_uInt32)xFieldContent->getLong(); break;
- case ::com::sun::star::uno::TypeClass_BOOLEAN : ::utl::setBOOL(pReturnArray[i],xFieldContent->getBoolean()); break;
+ case ::com::sun::star::uno::TypeClass_BOOLEAN : ::comphelper::setBOOL(pReturnArray[i],xFieldContent->getBoolean()); break;
default:
{
throw ::com::sun::star::lang::IllegalArgumentException();
@@ -1299,7 +1299,7 @@ void FmXGridPeer::propertyChange(const ::com::sun::star::beans::PropertyChangeEv
else if (pGrid && m_xColumns.is() && m_xColumns->hasElements())
{
// zunaechst raussuchen welche Column sich geaendert hat
- ::utl::InterfaceRef xCurrent;
+ ::comphelper::InterfaceRef xCurrent;
for (sal_Int32 i = 0; i < m_xColumns->getCount(); i++)
{
::cppu::extractInterface(xCurrent, m_xColumns->getByIndex(i));
@@ -1316,7 +1316,7 @@ void FmXGridPeer::propertyChange(const ::com::sun::star::beans::PropertyChangeEv
if (evt.PropertyName == FM_PROP_LABEL)
{
- String aName = ::utl::getString(evt.NewValue);
+ String aName = ::comphelper::getString(evt.NewValue);
if (aName != pGrid->GetColumnTitle(nId))
pGrid->SetColumnTitle(nId, aName);
}
@@ -1350,7 +1350,7 @@ void FmXGridPeer::propertyChange(const ::com::sun::star::beans::PropertyChangeEv
{
DBG_ASSERT(evt.NewValue.getValueType().getTypeClass() == ::com::sun::star::uno::TypeClass_BOOLEAN,
"FmXGridPeer::propertyChange : the property 'hidden' should be of type boolean !");
- if (::utl::getBOOL(evt.NewValue))
+ if (::comphelper::getBOOL(evt.NewValue))
pGrid->HideColumn(nId);
else
pGrid->ShowColumn(nId);
@@ -1437,7 +1437,7 @@ void FmXGridPeer::cursorMoved(const ::com::sun::star::lang::EventObject& _rEvent
FmGridControl* pGrid = (FmGridControl*) GetWindow();
// we are not interested in move to insert row only in the resetted event
// which is fired after positioning an the insert row
- if (pGrid && pGrid->IsOpen() && !::utl::getBOOL(::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > (_rEvent.Source, ::com::sun::star::uno::UNO_QUERY)->getPropertyValue(FM_PROP_ISNEW)))
+ if (pGrid && pGrid->IsOpen() && !::comphelper::getBOOL(::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > (_rEvent.Source, ::com::sun::star::uno::UNO_QUERY)->getPropertyValue(FM_PROP_ISNEW)))
pGrid->positioned(_rEvent);
}
@@ -1627,20 +1627,20 @@ void FmXGridPeer::elementInserted(const ::com::sun::star::container::ContainerEv
addColumnListeners(xSet);
::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > xNewColumn(xSet);
- String aName = ::utl::getString(xNewColumn->getPropertyValue(FM_PROP_LABEL));
+ String aName = ::comphelper::getString(xNewColumn->getPropertyValue(FM_PROP_LABEL));
::com::sun::star::uno::Any aWidth = xNewColumn->getPropertyValue(FM_PROP_WIDTH);
sal_Int32 nWidth = 0;
if (aWidth >>= nWidth)
nWidth = pGrid->LogicToPixel(Point(nWidth,0),MAP_10TH_MM).X();
- pGrid->AppendColumn(aName, nWidth, (sal_Int16)::utl::getINT32(evt.Accessor));
+ pGrid->AppendColumn(aName, nWidth, (sal_Int16)::comphelper::getINT32(evt.Accessor));
// jetzt die Spalte setzen
- DbGridColumn* pCol = pGrid->GetColumns().GetObject(::utl::getINT32(evt.Accessor));
+ DbGridColumn* pCol = pGrid->GetColumns().GetObject(::comphelper::getINT32(evt.Accessor));
pCol->setModel(xNewColumn);
::com::sun::star::uno::Any aHidden = xNewColumn->getPropertyValue(FM_PROP_HIDDEN);
- if (::utl::getBOOL(aHidden))
+ if (::comphelper::getBOOL(aHidden))
pGrid->HideColumn(pCol->GetId());
}
@@ -1658,15 +1658,15 @@ void FmXGridPeer::elementReplaced(const ::com::sun::star::container::ContainerEv
::cppu::extractInterface(xNewColumn, evt.Element);
::cppu::extractInterface(xOldColumn, evt.ReplacedElement);
- pGrid->RemoveColumn(pGrid->GetColumnIdFromModelPos(::utl::getINT32(evt.Accessor)));
+ pGrid->RemoveColumn(pGrid->GetColumnIdFromModelPos(::comphelper::getINT32(evt.Accessor)));
removeColumnListeners(xOldColumn);
- String aName = ::utl::getString(xNewColumn->getPropertyValue(FM_PROP_LABEL));
+ String aName = ::comphelper::getString(xNewColumn->getPropertyValue(FM_PROP_LABEL));
::com::sun::star::uno::Any aWidth = xNewColumn->getPropertyValue(FM_PROP_WIDTH);
sal_Int32 nWidth = 0;
if (aWidth >>= nWidth)
nWidth = pGrid->LogicToPixel(Point(nWidth,0),MAP_10TH_MM).X();
- pGrid->AppendColumn(aName, nWidth, (sal_Int16)::utl::getINT32(evt.Accessor));
+ pGrid->AppendColumn(aName, nWidth, (sal_Int16)::comphelper::getINT32(evt.Accessor));
addColumnListeners(xNewColumn);
}
@@ -1680,7 +1680,7 @@ void FmXGridPeer::elementRemoved(const ::com::sun::star::container::ContainerEve
if (!pGrid || !m_xColumns.is() || pGrid->IsInColumnMove() || m_xColumns->getCount() == ((sal_Int32)pGrid->GetModelColCount()))
return;
- pGrid->RemoveColumn(pGrid->GetColumnIdFromModelPos(::utl::getINT32(evt.Accessor)));
+ pGrid->RemoveColumn(pGrid->GetColumnIdFromModelPos(::comphelper::getINT32(evt.Accessor)));
::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > xOldColumn;
::cppu::extractInterface(xOldColumn, evt.Element);
@@ -1697,7 +1697,7 @@ void FmXGridPeer::setProperty( const ::rtl::OUString& PropertyName, const ::com:
{
case FM_ATTR_HELPURL:
{
- String sHelpURL(::utl::getString(Value));
+ String sHelpURL(::comphelper::getString(Value));
String sPattern;
sPattern.AssignAscii("HID:");
if (sHelpURL.Equals(sPattern, 0, sPattern.Len()))
@@ -1708,18 +1708,18 @@ void FmXGridPeer::setProperty( const ::rtl::OUString& PropertyName, const ::com:
}
break;
case FM_ATTR_DISPLAYSYNCHRON:
- pGrid->setDisplaySynchron(::utl::getBOOL(Value));
+ pGrid->setDisplaySynchron(::comphelper::getBOOL(Value));
break;
case FM_ATTR_CURSORCOLOR:
if (bVoid)
pGrid->SetCursorColor(COL_TRANSPARENT);
else
- pGrid->SetCursorColor(Color(::utl::getINT32(Value)));
+ pGrid->SetCursorColor(Color(::comphelper::getINT32(Value)));
if (isDesignMode())
pGrid->Invalidate();
break;
case FM_ATTR_ALWAYSSHOWCURSOR:
- pGrid->EnablePermanentCursor(::utl::getBOOL(Value));
+ pGrid->EnablePermanentCursor(::comphelper::getBOOL(Value));
if (isDesignMode())
pGrid->Invalidate();
break;
@@ -1732,7 +1732,7 @@ void FmXGridPeer::setProperty( const ::rtl::OUString& PropertyName, const ::com:
::com::sun::star::awt::FontDescriptor aFont;
if (Value >>= aFont)
{
- if (::utl::operator==(aFont, ::utl::getDefaultFont())) // ist das der Default
+ if (::comphelper::operator==(aFont, ::comphelper::getDefaultFont())) // ist das der Default
pGrid->SetControlFont( Font() );
else
pGrid->SetControlFont( ImplCreateFont( aFont ) );
@@ -1740,7 +1740,7 @@ void FmXGridPeer::setProperty( const ::rtl::OUString& PropertyName, const ::com:
// if our row-height property is void (which means "calculate it font-dependent") we have
// to adjust the control's row height
::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > xModelSet(getColumns(), ::com::sun::star::uno::UNO_QUERY);
- if (xModelSet.is() && ::utl::hasProperty(FM_PROP_ROWHEIGHT, xModelSet))
+ if (xModelSet.is() && ::comphelper::hasProperty(FM_PROP_ROWHEIGHT, xModelSet))
{
::com::sun::star::uno::Any aHeight = xModelSet->getPropertyValue(FM_PROP_ROWHEIGHT);
if (!aHeight.hasValue())
@@ -1758,7 +1758,7 @@ void FmXGridPeer::setProperty( const ::rtl::OUString& PropertyName, const ::com:
}
else
{
- Color aColor( ::utl::getINT32(Value) );
+ Color aColor( ::comphelper::getINT32(Value) );
pGrid->SetBackground( aColor );
pGrid->SetControlBackground( aColor );
}
@@ -1770,7 +1770,7 @@ void FmXGridPeer::setProperty( const ::rtl::OUString& PropertyName, const ::com:
}
else
{
- Color aColor( ::utl::getINT32(Value) );
+ Color aColor( ::comphelper::getINT32(Value) );
pGrid->SetTextColor( aColor );
pGrid->SetControlForeground( aColor );
}
@@ -2050,7 +2050,7 @@ sal_Bool FmXGridPeer::hasElements() throw( ::com::sun::star::uno::RuntimeExcepti
//------------------------------------------------------------------------------
::com::sun::star::uno::Reference< ::com::sun::star::container::XEnumeration > FmXGridPeer::createEnumeration() throw( ::com::sun::star::uno::RuntimeException )
{
- return new ::utl::OEnumerationByIndex(this);
+ return new ::comphelper::OEnumerationByIndex(this);
}
// ::com::sun::star::container::XIndexAccess
@@ -2115,9 +2115,9 @@ void FmXGridPeer::setMode(const ::rtl::OUString& Mode) throw( ::com::sun::star::
}
//------------------------------------------------------------------------------
-::utl::StringSequence FmXGridPeer::getSupportedModes() throw( ::com::sun::star::uno::RuntimeException )
+::comphelper::StringSequence FmXGridPeer::getSupportedModes() throw( ::com::sun::star::uno::RuntimeException )
{
- static ::utl::StringSequence aModes;
+ static ::comphelper::StringSequence aModes;
if (!aModes.getLength())
{
aModes.realloc(2);
@@ -2131,7 +2131,7 @@ void FmXGridPeer::setMode(const ::rtl::OUString& Mode) throw( ::com::sun::star::
//------------------------------------------------------------------------------
sal_Bool FmXGridPeer::supportsMode(const ::rtl::OUString& Mode) throw( ::com::sun::star::uno::RuntimeException )
{
- ::utl::StringSequence aModes(getSupportedModes());
+ ::comphelper::StringSequence aModes(getSupportedModes());
const ::rtl::OUString* pModes = aModes.getConstArray();
for (sal_Int32 i = aModes.getLength(); i > 0; )
{
@@ -2392,7 +2392,7 @@ void FmXGridPeer::resetted(const ::com::sun::star::lang::EventObject& rEvent) th
// let an ::com::sun::star::util::URL-transformer normalize the URLs
::com::sun::star::uno::Reference< ::com::sun::star::util::XURLTransformer > xTransformer(
- ::utl::getProcessServiceFactory()->createInstance(
+ ::comphelper::getProcessServiceFactory()->createInstance(
::rtl::OUString::createFromAscii("com.sun.star.util.URLTransformer")),
::com::sun::star::uno::UNO_QUERY);
pSupported = aSupported.getArray();
diff --git a/svx/source/fmcomp/gridcell.cxx b/svx/source/fmcomp/gridcell.cxx
index bdd4d0c0ec8e..f1f7c9df0c0e 100644
--- a/svx/source/fmcomp/gridcell.cxx
+++ b/svx/source/fmcomp/gridcell.cxx
@@ -2,9 +2,9 @@
*
* $RCSfile: gridcell.cxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 17:01:16 $
+ * last change: $Author: fs $ $Date: 2000-10-20 14:13:45 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -147,20 +147,20 @@
#include "fmimplids.hxx"
#endif
-#ifndef _UTL_NUMBERS_HXX_
-#include <unotools/numbers.hxx>
+#ifndef _COMPHELPER_NUMBERS_HXX_
+#include <comphelper/numbers.hxx>
#endif
-#ifndef _UTL_DB_CONVERSION_HXX_
-#include <unotools/dbconversion.hxx>
+#ifndef _DBHELPER_DBCONVERSION_HXX_
+#include <connectivity/dbconversion.hxx>
#endif
-#ifndef _UTL_PROPERTY_HXX_
-#include <unotools/property.hxx>
+#ifndef _COMPHELPER_PROPERTY_HXX_
+#include <comphelper/property.hxx>
#endif
-#ifndef _UTL_UNO3_DB_TOOLS_HXX_
-#include <unotools/dbtools.hxx>
+#ifndef _CONNECTIVITY_DBTOOLS_HXX_
+#include <connectivity/dbtools.hxx>
#endif
-#ifndef _UNOTOOLS_DATETIME_HXX_
-#include <unotools/datetime.hxx>
+#ifndef _COMPHELPER_DATETIME_HXX_
+#include <comphelper/datetime.hxx>
#endif
#ifndef _CPPUHELPER_EXTRACT_HXX_
#include <cppuhelper/extract.hxx>
@@ -189,9 +189,9 @@ void DbGridColumn::CreateControl(sal_Int32 _nFieldPos, const ::com::sun::star::u
m_xField = xField;
xField->getPropertyValue(FM_PROP_FORMATKEY) >>= m_nFormatKey;
m_nFieldPos = (sal_Int16)_nFieldPos;
- m_bReadOnly = ::utl::getBOOL(xField->getPropertyValue(FM_PROP_ISREADONLY));
- m_bAutoValue = ::utl::getBOOL(xField->getPropertyValue(FM_PROP_AUTOINCREMENT));
- m_nFieldType = ::utl::getINT32(xField->getPropertyValue(FM_PROP_FIELDTYPE));
+ m_bReadOnly = ::comphelper::getBOOL(xField->getPropertyValue(FM_PROP_ISREADONLY));
+ m_bAutoValue = ::comphelper::getBOOL(xField->getPropertyValue(FM_PROP_AUTOINCREMENT));
+ m_nFieldType = ::comphelper::getINT32(xField->getPropertyValue(FM_PROP_FIELDTYPE));
switch (m_nFieldType)
{
@@ -689,9 +689,9 @@ void DbTextField::Init(Window* pParent, const ::com::sun::star::uno::Reference<
sal_Int16 nAlignment = m_rColumn.SetAlignmentFromModel(-1);
::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > xModel(m_rColumn.getModel());
- sal_Bool bReadOnly = ::utl::getBOOL(xModel->getPropertyValue(FM_PROP_READONLY));
- sal_Bool bEnable = ::utl::getBOOL(xModel->getPropertyValue(FM_PROP_ENABLED));
- sal_Int16 nMaxLen = ::utl::getINT16(xModel->getPropertyValue(FM_PROP_MAXTEXTLEN));
+ sal_Bool bReadOnly = ::comphelper::getBOOL(xModel->getPropertyValue(FM_PROP_READONLY));
+ sal_Bool bEnable = ::comphelper::getBOOL(xModel->getPropertyValue(FM_PROP_ENABLED));
+ sal_Int16 nMaxLen = ::comphelper::getINT16(xModel->getPropertyValue(FM_PROP_MAXTEXTLEN));
switch (nAlignment)
{
case ::com::sun::star::awt::TextAlign::RIGHT:
@@ -717,7 +717,7 @@ void DbTextField::Init(Window* pParent, const ::com::sun::star::uno::Reference<
m_pWindow->Enable(bEnable);
if (m_rColumn.GetParent().getNumberFormatter().is() && m_rColumn.GetKey())
- m_nKeyType = utl::getNumberFormatType(m_rColumn.GetParent().getNumberFormatter()->getNumberFormatsSupplier()->getNumberFormats(), m_rColumn.GetKey());
+ m_nKeyType = comphelper::getNumberFormatType(m_rColumn.GetParent().getNumberFormatter()->getNumberFormatsSupplier()->getNumberFormats(), m_rColumn.GetKey());
DbCellControl::Init(pParent, xCursor);
}
@@ -733,7 +733,7 @@ XubString DbTextField::GetFormatText(const ::com::sun::star::uno::Reference< ::c
{
::rtl::OUString aString;
if (_xVariant.is())
- aString = ::utl::DBTypeConversion::getValue(_xVariant,
+ aString = ::dbtools::DBTypeConversion::getValue(_xVariant,
xFormatter,
m_rColumn.GetParent().getNullDate(),
m_rColumn.GetKey(),
@@ -768,7 +768,7 @@ DbFormattedField::DbFormattedField(DbGridColumn& _rColumn)
DBG_CTOR(DbFormattedField,NULL);
// if our model's format key changes we want to propagate the new value to our windows
- m_pFormatListener = new ::utl::OPropertyChangeMultiplexer(this, ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > (_rColumn.getModel(), ::com::sun::star::uno::UNO_QUERY));
+ m_pFormatListener = new ::comphelper::OPropertyChangeMultiplexer(this, ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > (_rColumn.getModel(), ::com::sun::star::uno::UNO_QUERY));
m_pFormatListener->acquire();
m_pFormatListener->addProperty(FM_PROP_FORMATKEY);
}
@@ -789,9 +789,9 @@ void DbFormattedField::Init(Window* pParent, const ::com::sun::star::uno::Refere
sal_Int16 nAlignment = m_rColumn.SetAlignmentFromModel(-1);
::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > xUnoModel = m_rColumn.getModel();
- sal_Bool bReadOnly = ::utl::getBOOL(xUnoModel->getPropertyValue(FM_PROP_READONLY));
- sal_Bool bEnable = ::utl::getBOOL(xUnoModel->getPropertyValue(FM_PROP_ENABLED));
- sal_Int16 nMaxLen = ::utl::getINT16(xUnoModel->getPropertyValue(FM_PROP_MAXTEXTLEN));
+ sal_Bool bReadOnly = ::comphelper::getBOOL(xUnoModel->getPropertyValue(FM_PROP_READONLY));
+ sal_Bool bEnable = ::comphelper::getBOOL(xUnoModel->getPropertyValue(FM_PROP_ENABLED));
+ sal_Int16 nMaxLen = ::comphelper::getINT16(xUnoModel->getPropertyValue(FM_PROP_MAXTEXTLEN));
switch (nAlignment)
{
@@ -835,7 +835,7 @@ void DbFormattedField::Init(Window* pParent, const ::com::sun::star::uno::Refere
sal_Int32 nFormatKey = -1;
// mal sehen, ob das Model einen hat ...
- DBG_ASSERT(::utl::hasProperty(FM_PROP_FORMATSSUPPLIER, xUnoModel), "DbFormattedField::Init : invalid UNO model !");
+ DBG_ASSERT(::comphelper::hasProperty(FM_PROP_FORMATSSUPPLIER, xUnoModel), "DbFormattedField::Init : invalid UNO model !");
::com::sun::star::uno::Any aSupplier( xUnoModel->getPropertyValue(FM_PROP_FORMATSSUPPLIER));
if (aSupplier.hasValue())
{
@@ -847,7 +847,7 @@ void DbFormattedField::Init(Window* pParent, const ::com::sun::star::uno::Refere
if (aFmtKey.hasValue())
{
DBG_ASSERT(aFmtKey.getValueType().getTypeClass() == ::com::sun::star::uno::TypeClass_LONG, "DbFormattedField::Init : invalid format key property (no sal_Int32) !");
- nFormatKey = ::utl::getINT32(aFmtKey);
+ nFormatKey = ::comphelper::getINT32(aFmtKey);
}
else
{
@@ -869,10 +869,10 @@ void DbFormattedField::Init(Window* pParent, const ::com::sun::star::uno::Refere
::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XRowSet > xCursorForm(xCursor, ::com::sun::star::uno::UNO_QUERY);
if (xCursorForm.is())
{ // wenn wir vom Cursor den Formatter nehmen, dann auch den Key vom Feld, an das wir gebunden sind
- m_xSupplier = ::utl::getNumberFormats(::utl::getConnection(xCursorForm), sal_False);
+ m_xSupplier = ::dbtools::getNumberFormats(::dbtools::getConnection(xCursorForm), sal_False);
if (m_rColumn.GetField().is())
- nFormatKey = ::utl::getINT32(m_rColumn.GetField()->getPropertyValue(FM_PROP_FORMATKEY));
+ nFormatKey = ::comphelper::getINT32(m_rColumn.GetField()->getPropertyValue(FM_PROP_FORMATKEY));
}
}
@@ -898,7 +898,7 @@ void DbFormattedField::Init(Window* pParent, const ::com::sun::star::uno::Refere
if (nFormatKey == -1)
nFormatKey = 0;
- m_nKeyType = utl::getNumberFormatType(m_xSupplier->getNumberFormats(), nFormatKey);
+ m_nKeyType = comphelper::getNumberFormatType(m_xSupplier->getNumberFormats(), nFormatKey);
((FormattedField*)m_pWindow)->SetFormatter(pFormatterUsed);
((FormattedField*)m_pPainter)->SetFormatter(pFormatterUsed);
@@ -913,13 +913,13 @@ void DbFormattedField::Init(Window* pParent, const ::com::sun::star::uno::Refere
if (m_rColumn.IsNumeric())
{
sal_Bool bClearMin = sal_True;
- if (::utl::hasProperty(FM_PROP_EFFECTIVE_MIN, xUnoModel))
+ if (::comphelper::hasProperty(FM_PROP_EFFECTIVE_MIN, xUnoModel))
{
::com::sun::star::uno::Any aMin( xUnoModel->getPropertyValue(FM_PROP_EFFECTIVE_MIN));
if (aMin.getValueType().getTypeClass() != ::com::sun::star::uno::TypeClass_VOID)
{
DBG_ASSERT(aMin.getValueType().getTypeClass() == ::com::sun::star::uno::TypeClass_DOUBLE, "DbFormattedField::Init : the model has an invalid min value !");
- double dMin = ::utl::getDouble(aMin);
+ double dMin = ::comphelper::getDouble(aMin);
((FormattedField*)m_pWindow)->SetMinValue(dMin);
((FormattedField*)m_pPainter)->SetMinValue(dMin);
bClearMin = sal_False;
@@ -931,13 +931,13 @@ void DbFormattedField::Init(Window* pParent, const ::com::sun::star::uno::Refere
((FormattedField*)m_pPainter)->ClearMinValue();
}
sal_Bool bClearMax = sal_True;
- if (::utl::hasProperty(FM_PROP_EFFECTIVE_MAX, xUnoModel))
+ if (::comphelper::hasProperty(FM_PROP_EFFECTIVE_MAX, xUnoModel))
{
::com::sun::star::uno::Any aMin( xUnoModel->getPropertyValue(FM_PROP_EFFECTIVE_MAX));
if (aMin.getValueType().getTypeClass() != ::com::sun::star::uno::TypeClass_VOID)
{
DBG_ASSERT(aMin.getValueType().getTypeClass() == ::com::sun::star::uno::TypeClass_DOUBLE, "DbFormattedField::Init : the model has an invalid max value !");
- double dMin = ::utl::getDouble(aMin);
+ double dMin = ::comphelper::getDouble(aMin);
((FormattedField*)m_pWindow)->SetMaxValue(dMin);
((FormattedField*)m_pPainter)->SetMaxValue(dMin);
bClearMax = sal_False;
@@ -959,21 +959,21 @@ void DbFormattedField::Init(Window* pParent, const ::com::sun::star::uno::Refere
case ::com::sun::star::uno::TypeClass_DOUBLE:
if (m_rColumn.IsNumeric())
{
- ((FormattedField*)m_pWindow)->SetDefaultValue(::utl::getDouble(aDefault));
- ((FormattedField*)m_pPainter)->SetDefaultValue(::utl::getDouble(aDefault));
+ ((FormattedField*)m_pWindow)->SetDefaultValue(::comphelper::getDouble(aDefault));
+ ((FormattedField*)m_pPainter)->SetDefaultValue(::comphelper::getDouble(aDefault));
}
else
{
XubString sConverted;
Color* pDummy;
- pFormatterUsed->GetOutputString(::utl::getDouble(aDefault), 0, sConverted, &pDummy);
+ pFormatterUsed->GetOutputString(::comphelper::getDouble(aDefault), 0, sConverted, &pDummy);
((FormattedField*)m_pWindow)->SetDefaultText(sConverted);
((FormattedField*)m_pPainter)->SetDefaultText(sConverted);
}
break;
case ::com::sun::star::uno::TypeClass_STRING:
{
- XubString sDefault( UniString( ::utl::getString(aDefault) ) );
+ XubString sDefault( UniString( ::comphelper::getString(aDefault) ) );
if (m_rColumn.IsNumeric())
{
double dVal;
@@ -1006,8 +1006,8 @@ void DbFormattedField::_propertyChanged(const ::com::sun::star::beans::PropertyC
{
if (evt.PropertyName.compareTo(FM_PROP_FORMATKEY) == COMPARE_EQUAL)
{
- sal_Int32 nNewKey = evt.NewValue.hasValue() ? ::utl::getINT32(evt.NewValue) : 0;
- m_nKeyType = utl::getNumberFormatType(m_xSupplier->getNumberFormats(), nNewKey);
+ sal_Int32 nNewKey = evt.NewValue.hasValue() ? ::comphelper::getINT32(evt.NewValue) : 0;
+ m_nKeyType = comphelper::getNumberFormatType(m_xSupplier->getNumberFormats(), nNewKey);
DBG_ASSERT(m_pWindow && m_pPainter, "DbFormattedField::_propertyChanged : where are my windows ?");
if (m_pWindow)
@@ -1036,7 +1036,7 @@ XubString DbFormattedField::GetFormatText(const ::com::sun::star::uno::Reference
// ein double-Feld bindet und als Text formatiert, liefert m_rColumn.IsNumeric() sal_True. Das heisst
// also einfach, dass ich den Inhalt der Variant mittels getDouble abfragen kann, und dann kann
// ich den Rest (die Formatierung) dem FormattedField ueberlassen.
- double dValue = ::utl::DBTypeConversion::getValue(_xVariant, m_rColumn.GetParent().getNullDate(), m_nKeyType);
+ double dValue = ::dbtools::DBTypeConversion::getValue(_xVariant, m_rColumn.GetParent().getNullDate(), m_nKeyType);
if (_xVariant->wasNull())
return aText;
((FormattedField*)m_pPainter)->SetValue(dValue);
@@ -1072,7 +1072,7 @@ void DbFormattedField::UpdateFromField(const ::com::sun::star::uno::Reference< :
// ein double-Feld bindet und als Text formatiert, liefert m_rColumn.IsNumeric() sal_True. Das heisst
// also einfach, dass ich den Inhalt der Variant mittels getDouble abfragen kann, und dann kann
// ich den Rest (die Formatierung) dem FormattedField ueberlassen.
- double dValue = ::utl::DBTypeConversion::getValue(_xVariant, m_rColumn.GetParent().getNullDate(), m_nKeyType);
+ double dValue = ::dbtools::DBTypeConversion::getValue(_xVariant, m_rColumn.GetParent().getNullDate(), m_nKeyType);
if (_xVariant->wasNull())
m_pWindow->SetText(XubString());
else
@@ -1111,7 +1111,7 @@ void DbCheckBox::Init(Window* pParent, const ::com::sun::star::uno::Reference< :
{
m_bTransparent = sal_True;
::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > xModel(m_rColumn.getModel());
- sal_Bool bEnable = ::utl::getBOOL(xModel->getPropertyValue(FM_PROP_ENABLED));
+ sal_Bool bEnable = ::comphelper::getBOOL(xModel->getPropertyValue(FM_PROP_ENABLED));
m_pWindow = new DbCheckBoxCtrl(pParent);
m_pPainter = new DbCheckBoxCtrl(pParent);
@@ -1174,8 +1174,8 @@ sal_Bool DbCheckBox::Commit()
void DbPatternField::Init(Window* pParent, const ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XRowSet >& xCursor)
{
::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > xModel(m_rColumn.getModel());
- sal_Bool bReadOnly = ::utl::getBOOL(xModel->getPropertyValue(FM_PROP_READONLY));
- sal_Bool bEnable = ::utl::getBOOL(xModel->getPropertyValue(FM_PROP_ENABLED));
+ sal_Bool bReadOnly = ::comphelper::getBOOL(xModel->getPropertyValue(FM_PROP_READONLY));
+ sal_Bool bEnable = ::comphelper::getBOOL(xModel->getPropertyValue(FM_PROP_ENABLED));
m_rColumn.SetAlignmentFromModel(-1);
@@ -1187,7 +1187,7 @@ void DbPatternField::Init(Window* pParent, const ::com::sun::star::uno::Referenc
xModel->getPropertyValue(FM_PROP_LITERALMASK) >>= aLitMask;
::rtl::OUString aEditMask;
xModel->getPropertyValue(FM_PROP_EDITMASK) >>= aEditMask;
- sal_Bool bStrict = ::utl::getBOOL(xModel->getPropertyValue(FM_PROP_STRICTFORMAT));
+ sal_Bool bStrict = ::comphelper::getBOOL(xModel->getPropertyValue(FM_PROP_STRICTFORMAT));
ByteString aAsciiListMask((const sal_Unicode*)aLitMask, RTL_TEXTENCODING_ASCII_US);
pField->SetMask(aAsciiListMask, aEditMask);
@@ -1238,13 +1238,13 @@ sal_Bool DbPatternField::Commit()
void DbNumericField::Init(Window* pParent, const ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XRowSet >& xCursor)
{
::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > xModel(m_rColumn.getModel());
- sal_Bool bReadOnly = ::utl::getBOOL(xModel->getPropertyValue(FM_PROP_READONLY));
- sal_Bool bEnable = ::utl::getBOOL(xModel->getPropertyValue(FM_PROP_ENABLED));
+ sal_Bool bReadOnly = ::comphelper::getBOOL(xModel->getPropertyValue(FM_PROP_READONLY));
+ sal_Bool bEnable = ::comphelper::getBOOL(xModel->getPropertyValue(FM_PROP_ENABLED));
m_rColumn.SetAlignmentFromModel(::com::sun::star::awt::TextAlign::RIGHT);
DoubleNumericField* pField;
- if (::utl::getBOOL(xModel->getPropertyValue(FM_PROP_SPIN)))
+ if (::comphelper::getBOOL(xModel->getPropertyValue(FM_PROP_SPIN)))
{
pField = new DoubleNumericField(pParent, WB_REPEAT | WB_SPIN);
m_pPainter= new DoubleNumericField(pParent, WB_REPEAT | WB_SPIN);
@@ -1259,12 +1259,12 @@ void DbNumericField::Init(Window* pParent, const ::com::sun::star::uno::Referenc
pField->EnableEmptyField(sal_True);
((DoubleNumericField*)m_pPainter)->EnableEmptyField(sal_True);
- sal_Int16 nScale = ::utl::getINT16(xModel->getPropertyValue(FM_PROP_DECIMAL_ACCURACY));
- sal_Int32 nMin = (sal_Int32)::utl::getDouble(xModel->getPropertyValue(FM_PROP_VALUEMIN));
- sal_Int32 nMax = (sal_Int32)::utl::getDouble(xModel->getPropertyValue(FM_PROP_VALUEMAX));
- sal_Int32 nStep = (sal_Int32)::utl::getDouble(xModel->getPropertyValue(FM_PROP_VALUESTEP));
- sal_Bool bStrict = ::utl::getBOOL(xModel->getPropertyValue(FM_PROP_STRICTFORMAT));
- sal_Bool bThousand = ::utl::getBOOL(xModel->getPropertyValue(FM_PROP_SHOWTHOUSANDSEP));
+ sal_Int16 nScale = ::comphelper::getINT16(xModel->getPropertyValue(FM_PROP_DECIMAL_ACCURACY));
+ sal_Int32 nMin = (sal_Int32)::comphelper::getDouble(xModel->getPropertyValue(FM_PROP_VALUEMIN));
+ sal_Int32 nMax = (sal_Int32)::comphelper::getDouble(xModel->getPropertyValue(FM_PROP_VALUEMAX));
+ sal_Int32 nStep = (sal_Int32)::comphelper::getDouble(xModel->getPropertyValue(FM_PROP_VALUESTEP));
+ sal_Bool bStrict = ::comphelper::getBOOL(xModel->getPropertyValue(FM_PROP_STRICTFORMAT));
+ sal_Bool bThousand = ::comphelper::getBOOL(xModel->getPropertyValue(FM_PROP_SHOWTHOUSANDSEP));
pField->SetMinValue(nMin);
pField->SetMaxValue(nMax);
@@ -1282,7 +1282,7 @@ void DbNumericField::Init(Window* pParent, const ::com::sun::star::uno::Referenc
::com::sun::star::uno::Reference< ::com::sun::star::util::XNumberFormatsSupplier > xSupplier;
::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XRowSet > xForm(xCursor, ::com::sun::star::uno::UNO_QUERY);
if (xForm.is())
- xSupplier = ::utl::getNumberFormats(::utl::getConnection(xForm), sal_True);
+ xSupplier = ::dbtools::getNumberFormats(::dbtools::getConnection(xForm), sal_True);
SvNumberFormatter* pFormatterUsed = NULL;
if (xSupplier.is())
{
@@ -1366,13 +1366,13 @@ sal_Bool DbNumericField::Commit()
void DbCurrencyField::Init(Window* pParent, const ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XRowSet >& xCursor)
{
::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > xModel(m_rColumn.getModel());
- sal_Bool bReadOnly = ::utl::getBOOL(xModel->getPropertyValue(FM_PROP_READONLY));
- sal_Bool bEnable = ::utl::getBOOL(xModel->getPropertyValue(FM_PROP_ENABLED));
+ sal_Bool bReadOnly = ::comphelper::getBOOL(xModel->getPropertyValue(FM_PROP_READONLY));
+ sal_Bool bEnable = ::comphelper::getBOOL(xModel->getPropertyValue(FM_PROP_ENABLED));
m_rColumn.SetAlignmentFromModel(::com::sun::star::awt::TextAlign::RIGHT);
LongCurrencyField* pField;
- if (::utl::getBOOL(xModel->getPropertyValue(FM_PROP_SPIN)))
+ if (::comphelper::getBOOL(xModel->getPropertyValue(FM_PROP_SPIN)))
{
pField = new LongCurrencyField(pParent, WB_REPEAT | WB_SPIN);
m_pPainter= new LongCurrencyField(pParent, WB_REPEAT | WB_SPIN);
@@ -1384,13 +1384,13 @@ void DbCurrencyField::Init(Window* pParent, const ::com::sun::star::uno::Referen
}
m_pWindow = pField;
- m_nScale = ::utl::getINT16(xModel->getPropertyValue(FM_PROP_DECIMAL_ACCURACY));
- double nMin = ::utl::getDouble(xModel->getPropertyValue(FM_PROP_VALUEMIN));
- double nMax = ::utl::getDouble(xModel->getPropertyValue(FM_PROP_VALUEMAX));
- double nStep = ::utl::getDouble(xModel->getPropertyValue(FM_PROP_VALUESTEP));
- sal_Bool bStrict = ::utl::getBOOL(xModel->getPropertyValue(FM_PROP_STRICTFORMAT));
- sal_Bool bThousand = ::utl::getBOOL(xModel->getPropertyValue(FM_PROP_SHOWTHOUSANDSEP));
- ::rtl::OUString aStr( ::utl::getString(xModel->getPropertyValue(FM_PROP_CURRENCYSYMBOL)));
+ m_nScale = ::comphelper::getINT16(xModel->getPropertyValue(FM_PROP_DECIMAL_ACCURACY));
+ double nMin = ::comphelper::getDouble(xModel->getPropertyValue(FM_PROP_VALUEMIN));
+ double nMax = ::comphelper::getDouble(xModel->getPropertyValue(FM_PROP_VALUEMAX));
+ double nStep = ::comphelper::getDouble(xModel->getPropertyValue(FM_PROP_VALUESTEP));
+ sal_Bool bStrict = ::comphelper::getBOOL(xModel->getPropertyValue(FM_PROP_STRICTFORMAT));
+ sal_Bool bThousand = ::comphelper::getBOOL(xModel->getPropertyValue(FM_PROP_SHOWTHOUSANDSEP));
+ ::rtl::OUString aStr( ::comphelper::getString(xModel->getPropertyValue(FM_PROP_CURRENCYSYMBOL)));
International aInternational( pField->GetInternational() );
aInternational.EnableNumThousandSep(bThousand);
@@ -1490,8 +1490,8 @@ void DbDateField::Init(Window* pParent, const ::com::sun::star::uno::Reference<
::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > xModel(m_rColumn.getModel());
WinBits aFieldBits = 0;
- sal_Bool bSpin = ::utl::getBOOL(xModel->getPropertyValue(FM_PROP_SPIN));
- sal_Bool bDropDown = !::utl::hasProperty(FM_PROP_DROPDOWN, xModel) || ::utl::getBOOL(xModel->getPropertyValue(FM_PROP_DROPDOWN));
+ sal_Bool bSpin = ::comphelper::getBOOL(xModel->getPropertyValue(FM_PROP_SPIN));
+ sal_Bool bDropDown = !::comphelper::hasProperty(FM_PROP_DROPDOWN, xModel) || ::comphelper::getBOOL(xModel->getPropertyValue(FM_PROP_DROPDOWN));
if (bSpin)
aFieldBits |= WB_REPEAT | WB_SPIN;
if (bDropDown)
@@ -1504,18 +1504,18 @@ void DbDateField::Init(Window* pParent, const ::com::sun::star::uno::Reference<
m_pWindow = pField;
- sal_Int16 nFormat = ::utl::getINT16(xModel->getPropertyValue(FM_PROP_DATEFORMAT));
- sal_Int32 nMin = ::utl::getINT32(xModel->getPropertyValue(FM_PROP_DATEMIN));
- sal_Int32 nMax = ::utl::getINT32(xModel->getPropertyValue(FM_PROP_DATEMAX));
- sal_Bool bStrict = ::utl::getBOOL(xModel->getPropertyValue(FM_PROP_STRICTFORMAT));
- sal_Bool bReadOnly = ::utl::getBOOL(xModel->getPropertyValue(FM_PROP_READONLY));
- sal_Bool bEnable = ::utl::getBOOL(xModel->getPropertyValue(FM_PROP_ENABLED));
+ sal_Int16 nFormat = ::comphelper::getINT16(xModel->getPropertyValue(FM_PROP_DATEFORMAT));
+ sal_Int32 nMin = ::comphelper::getINT32(xModel->getPropertyValue(FM_PROP_DATEMIN));
+ sal_Int32 nMax = ::comphelper::getINT32(xModel->getPropertyValue(FM_PROP_DATEMAX));
+ sal_Bool bStrict = ::comphelper::getBOOL(xModel->getPropertyValue(FM_PROP_STRICTFORMAT));
+ sal_Bool bReadOnly = ::comphelper::getBOOL(xModel->getPropertyValue(FM_PROP_READONLY));
+ sal_Bool bEnable = ::comphelper::getBOOL(xModel->getPropertyValue(FM_PROP_ENABLED));
::com::sun::star::uno::Any aCentury = xModel->getPropertyValue(FM_PROP_DATE_SHOW_CENTURY);
if (aCentury.getValueType().getTypeClass() != ::com::sun::star::uno::TypeClass_VOID)
{
International aInternational( pField->GetInternational() );
- aInternational.SetDateCentury(::utl::getBOOL(aCentury));
+ aInternational.SetDateCentury(::comphelper::getBOOL(aCentury));
pField->SetInternational(aInternational);
static_cast<DateField*>(m_pPainter)->SetInternational(aInternational);
@@ -1555,9 +1555,7 @@ XubString DbDateField::GetFormatText(const ::com::sun::star::uno::Reference< ::c
return XubString();
else
{
- Date aVclValue;
- ::utl::typeConvert(aValue, aVclValue);
- static_cast<DateField*>(m_pPainter)->SetDate(aVclValue);
+ static_cast<DateField*>(m_pPainter)->SetDate(Date(aValue.Day, aValue.Month, aValue.Year));
return m_pPainter->GetText();
}
}
@@ -1575,9 +1573,7 @@ void DbDateField::UpdateFromField(const ::com::sun::star::uno::Reference< ::com:
m_pWindow->SetText(XubString());
else
{
- Date aVclValue;
- ::utl::typeConvert(aValue, aVclValue);
- static_cast<DateField*>(m_pWindow)->SetDate(aVclValue);
+ static_cast<DateField*>(m_pWindow)->SetDate(Date(aValue.Day, aValue.Month, aValue.Year));
}
}
}
@@ -1600,13 +1596,13 @@ sal_Bool DbDateField::Commit()
void DbTimeField::Init(Window* pParent, const ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XRowSet >& xCursor)
{
::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > xModel(m_rColumn.getModel());
- sal_Bool bReadOnly = ::utl::getBOOL(xModel->getPropertyValue(FM_PROP_READONLY));
- sal_Bool bEnable = ::utl::getBOOL(xModel->getPropertyValue(FM_PROP_ENABLED));
+ sal_Bool bReadOnly = ::comphelper::getBOOL(xModel->getPropertyValue(FM_PROP_READONLY));
+ sal_Bool bEnable = ::comphelper::getBOOL(xModel->getPropertyValue(FM_PROP_ENABLED));
m_rColumn.SetAlignmentFromModel(::com::sun::star::awt::TextAlign::LEFT);
TimeField* pField;
- if (::utl::getBOOL(xModel->getPropertyValue(FM_PROP_SPIN)))
+ if (::comphelper::getBOOL(xModel->getPropertyValue(FM_PROP_SPIN)))
{
pField = new TimeField(pParent, WB_REPEAT | WB_SPIN);
m_pPainter= new TimeField(pParent, WB_REPEAT | WB_SPIN);
@@ -1618,10 +1614,10 @@ void DbTimeField::Init(Window* pParent, const ::com::sun::star::uno::Reference<
}
m_pWindow = pField;
- sal_Int16 nFormat = ::utl::getINT16(xModel->getPropertyValue(FM_PROP_TIMEFORMAT));
- sal_Int32 nMin = ::utl::getINT32(xModel->getPropertyValue(FM_PROP_TIMEMIN));
- sal_Int32 nMax = ::utl::getINT32(xModel->getPropertyValue(FM_PROP_TIMEMAX));
- sal_Bool bStrict = ::utl::getBOOL(xModel->getPropertyValue(FM_PROP_STRICTFORMAT));
+ sal_Int16 nFormat = ::comphelper::getINT16(xModel->getPropertyValue(FM_PROP_TIMEFORMAT));
+ sal_Int32 nMin = ::comphelper::getINT32(xModel->getPropertyValue(FM_PROP_TIMEMIN));
+ sal_Int32 nMax = ::comphelper::getINT32(xModel->getPropertyValue(FM_PROP_TIMEMAX));
+ sal_Bool bStrict = ::comphelper::getBOOL(xModel->getPropertyValue(FM_PROP_STRICTFORMAT));
pField->SetExtFormat( (ExtTimeFieldFormat)nFormat);
pField->SetMin(nMin);
@@ -1656,9 +1652,7 @@ XubString DbTimeField::GetFormatText(const ::com::sun::star::uno::Reference< ::c
return XubString();
else
{
- Time aVclTime;
- ::utl::typeConvert(aValue, aVclTime);
- static_cast<TimeField*>(m_pPainter)->SetTime(aVclTime);
+ static_cast<TimeField*>(m_pPainter)->SetTime(Time(aValue.Hours, aValue.Minutes, aValue.Seconds, aValue.HundredthSeconds));
return m_pPainter->GetText();
}
}
@@ -1676,9 +1670,7 @@ void DbTimeField::UpdateFromField(const ::com::sun::star::uno::Reference< ::com:
m_pWindow->SetText(XubString());
else
{
- Time aVclTime;
- ::utl::typeConvert(aValue, aVclTime);
- static_cast<TimeField*>(m_pWindow)->SetTime(aVclTime);
+ static_cast<TimeField*>(m_pWindow)->SetTime(Time(aValue.Hours, aValue.Minutes, aValue.Seconds, aValue.HundredthSeconds));
}
}
}
@@ -1718,7 +1710,7 @@ void DbComboBox::SetList(const ::com::sun::star::uno::Any& rItems)
DbComboBoxCtrl* pField = (DbComboBoxCtrl*)m_pWindow;
pField->Clear();
- ::utl::StringSequence aTest;
+ ::comphelper::StringSequence aTest;
if (rItems >>= aTest)
{
const ::rtl::OUString* pStrings = aTest.getConstArray();
@@ -1732,8 +1724,8 @@ void DbComboBox::SetList(const ::com::sun::star::uno::Any& rItems)
void DbComboBox::Init(Window* pParent, const ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XRowSet >& xCursor)
{
::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > xModel(m_rColumn.getModel());
- sal_Bool bReadOnly = ::utl::getBOOL(xModel->getPropertyValue(FM_PROP_READONLY));
- sal_Bool bEnable = ::utl::getBOOL(xModel->getPropertyValue(FM_PROP_ENABLED));
+ sal_Bool bReadOnly = ::comphelper::getBOOL(xModel->getPropertyValue(FM_PROP_READONLY));
+ sal_Bool bEnable = ::comphelper::getBOOL(xModel->getPropertyValue(FM_PROP_ENABLED));
m_rColumn.SetAlignmentFromModel(::com::sun::star::awt::TextAlign::LEFT);
@@ -1749,16 +1741,16 @@ void DbComboBox::Init(Window* pParent, const ::com::sun::star::uno::Reference< :
aSettings.SetStyleSettings(aStyleSettings);
m_pWindow->SetSettings(aSettings, sal_True);
- sal_Int16 nLines = ::utl::getINT16(xModel->getPropertyValue(FM_PROP_LINECOUNT));
+ sal_Int16 nLines = ::comphelper::getINT16(xModel->getPropertyValue(FM_PROP_LINECOUNT));
::com::sun::star::uno::Any aItems = xModel->getPropertyValue(FM_PROP_STRINGITEMLIST);
if (m_rColumn.GetParent().getNumberFormatter().is())
- m_nKeyType = utl::getNumberFormatType(m_rColumn.GetParent().getNumberFormatter()->getNumberFormatsSupplier()->getNumberFormats(), m_rColumn.GetKey());
+ m_nKeyType = comphelper::getNumberFormatType(m_rColumn.GetParent().getNumberFormatter()->getNumberFormatsSupplier()->getNumberFormats(), m_rColumn.GetKey());
SetList(aItems);
// Am Model horchen, um Aenderungen der Stringliste mitzubekommen
- ::utl::OPropertyChangeMultiplexer* pMultiplexer = new ::utl::OPropertyChangeMultiplexer(this, ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > (xModel, ::com::sun::star::uno::UNO_QUERY));
+ ::comphelper::OPropertyChangeMultiplexer* pMultiplexer = new ::comphelper::OPropertyChangeMultiplexer(this, ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > (xModel, ::com::sun::star::uno::UNO_QUERY));
pMultiplexer->addProperty(FM_PROP_STRINGITEMLIST);
pField->SetDropDownLineCount(nLines);
@@ -1779,7 +1771,7 @@ XubString DbComboBox::GetFormatText(const ::com::sun::star::uno::Reference< ::co
{
::rtl::OUString aString;
if (_xVariant.is())
- aString = ::utl::DBTypeConversion::getValue(_xVariant,
+ aString = ::dbtools::DBTypeConversion::getValue(_xVariant,
xFormatter,
m_rColumn.GetParent().getNullDate(),
m_rColumn.GetKey(),
@@ -1824,7 +1816,7 @@ void DbListBox::SetList(const ::com::sun::star::uno::Any& rItems)
pField->Clear();
m_bBound = sal_False;
- ::utl::StringSequence aTest;
+ ::comphelper::StringSequence aTest;
if (rItems >>= aTest)
{
const ::rtl::OUString* pStrings = aTest.getConstArray();
@@ -1844,20 +1836,20 @@ void DbListBox::SetList(const ::com::sun::star::uno::Any& rItems)
void DbListBox::Init(Window* pParent, const ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XRowSet >& xCursor)
{
::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > xModel(m_rColumn.getModel());
- sal_Bool bEnable = ::utl::getBOOL(xModel->getPropertyValue(FM_PROP_ENABLED));
+ sal_Bool bEnable = ::comphelper::getBOOL(xModel->getPropertyValue(FM_PROP_ENABLED));
m_rColumn.SetAlignment(::com::sun::star::awt::TextAlign::LEFT);
DbListBoxCtrl* pField;
pField = new DbListBoxCtrl(pParent);
m_pWindow = pField;
- sal_Int16 nLines = ::utl::getINT16(xModel->getPropertyValue(FM_PROP_LINECOUNT));
+ sal_Int16 nLines = ::comphelper::getINT16(xModel->getPropertyValue(FM_PROP_LINECOUNT));
::com::sun::star::uno::Any aItems = xModel->getPropertyValue(FM_PROP_STRINGITEMLIST);
SetList(aItems);
// Am Model horchen, um Aenderungen der Stringliste mitzubekommen
- ::utl::OPropertyChangeMultiplexer* pMultiplexer = new ::utl::OPropertyChangeMultiplexer(this, ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > (xModel, ::com::sun::star::uno::UNO_QUERY));
+ ::comphelper::OPropertyChangeMultiplexer* pMultiplexer = new ::comphelper::OPropertyChangeMultiplexer(this, ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > (xModel, ::com::sun::star::uno::UNO_QUERY));
pMultiplexer->addProperty(FM_PROP_STRINGITEMLIST);
pField->SetDropDownLineCount(nLines);
@@ -1957,7 +1949,7 @@ void DbFilterField::Paint(OutputDevice& rDev, const Rectangle& rRect)
//------------------------------------------------------------------------------
void DbFilterField::SetList(const ::com::sun::star::uno::Any& rItems, sal_Bool bComboBox)
{
- ::utl::StringSequence aTest;
+ ::comphelper::StringSequence aTest;
rItems >>= aTest;
const ::rtl::OUString* pStrings = aTest.getConstArray();
sal_Int32 nItems = aTest.getLength();
@@ -1998,7 +1990,7 @@ void DbFilterField::CreateControl(Window* pParent, const ::com::sun::star::uno::
case ::com::sun::star::form::FormComponentType::LISTBOX:
{
m_pWindow = new DbListBoxCtrl(pParent);
- sal_Int16 nLines = ::utl::getINT16(xModel->getPropertyValue(FM_PROP_LINECOUNT));
+ sal_Int16 nLines = ::comphelper::getINT16(xModel->getPropertyValue(FM_PROP_LINECOUNT));
::com::sun::star::uno::Any aItems = xModel->getPropertyValue(FM_PROP_STRINGITEMLIST);
SetList(aItems, m_nControlClass == ::com::sun::star::form::FormComponentType::COMBOBOX);
static_cast<ListBox*>(m_pWindow)->SetDropDownLineCount(nLines);
@@ -2016,7 +2008,7 @@ void DbFilterField::CreateControl(Window* pParent, const ::com::sun::star::uno::
if (!m_bFilterList)
{
- sal_Int16 nLines = ::utl::getINT16(xModel->getPropertyValue(FM_PROP_LINECOUNT));
+ sal_Int16 nLines = ::comphelper::getINT16(xModel->getPropertyValue(FM_PROP_LINECOUNT));
::com::sun::star::uno::Any aItems = xModel->getPropertyValue(FM_PROP_STRINGITEMLIST);
SetList(aItems, m_nControlClass == ::com::sun::star::form::FormComponentType::COMBOBOX);
((ComboBox*)m_pWindow)->SetDropDownLineCount(nLines);
@@ -2046,12 +2038,12 @@ void DbFilterField::Init(Window* pParent, const ::com::sun::star::uno::Reference
if (xModel.is())
{
- m_bFilterList = ::utl::hasProperty(FM_PROP_FILTERPROPOSAL, xModel) && ::utl::getBOOL(xModel->getPropertyValue(FM_PROP_FILTERPROPOSAL));
+ m_bFilterList = ::comphelper::hasProperty(FM_PROP_FILTERPROPOSAL, xModel) && ::comphelper::getBOOL(xModel->getPropertyValue(FM_PROP_FILTERPROPOSAL));
if (m_bFilterList)
m_nControlClass = ::com::sun::star::form::FormComponentType::COMBOBOX;
else
{
- sal_Int16 nClassId = ::utl::getINT16(xModel->getPropertyValue(FM_PROP_CLASSID));
+ sal_Int16 nClassId = ::comphelper::getINT16(xModel->getPropertyValue(FM_PROP_CLASSID));
switch (nClassId)
{
case ::com::sun::star::form::FormComponentType::CHECKBOX:
@@ -2141,7 +2133,7 @@ sal_Bool DbFilterField::Commit()
::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XRowSet > xDataSourceRowSet(
*m_rColumn.GetParent().getDataSource(), ::com::sun::star::uno::UNO_QUERY);
::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XConnection > xConnection(
- ::utl::getConnection(xDataSourceRowSet));
+ ::dbtools::getConnection(xDataSourceRowSet));
pParseNode->ParseNodeToPredicateStr(aPreparedText,
xConnection->getMetaData(),
xNumberFormatter,
@@ -2228,7 +2220,7 @@ void DbFilterField::Update()
if (!xForm.is())
return;
- ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XConnection > xConnection = ::utl::getConnection(xForm);
+ ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XConnection > xConnection = ::dbtools::getConnection(xForm);
if (!xConnection.is())
return;
@@ -2249,7 +2241,7 @@ void DbFilterField::Update()
}
catch(...)
{
- ::utl::disposeComponent(xComposer);
+ ::comphelper::disposeComponent(xComposer);
return;
}
@@ -2266,8 +2258,8 @@ void DbFilterField::Update()
::cppu::extractInterface(xTablesNames, xComposerAsSet->getPropertyValue(FM_PROP_SELECTED_TABLES));
::cppu::extractInterface(xComposerFieldAsSet, xFieldNames->getByName(aName));
- if (xComposerFieldAsSet.is() && ::utl::hasProperty(FM_PROP_TABLENAME, xComposerFieldAsSet) &&
- ::utl::hasProperty(FM_PROP_FIELDSOURCE, xComposerFieldAsSet))
+ if (xComposerFieldAsSet.is() && ::comphelper::hasProperty(FM_PROP_TABLENAME, xComposerFieldAsSet) &&
+ ::comphelper::hasProperty(FM_PROP_FIELDSOURCE, xComposerFieldAsSet))
{
::rtl::OUString aFieldName;
::rtl::OUString aTableName;
@@ -2322,7 +2314,7 @@ void DbFilterField::Update()
}
catch(...)
{
- ::utl::disposeComponent(xStatement);
+ ::comphelper::disposeComponent(xStatement);
return;
}
@@ -2330,14 +2322,14 @@ void DbFilterField::Update()
vector< ::rtl::OUString > aStringList;
aStringList.reserve(16);
::rtl::OUString aStr;
- Date aNullDate = m_rColumn.GetParent().getNullDate();
+ com::sun::star::util::Date aNullDate = m_rColumn.GetParent().getNullDate();
sal_Int32 nFormatKey = m_rColumn.GetKey();
::com::sun::star::uno::Reference< ::com::sun::star::util::XNumberFormatter > xFormatter = m_rColumn.GetParent().getNumberFormatter();
- sal_Int16 nKeyType = ::utl::getNumberFormatType(xFormatter->getNumberFormatsSupplier()->getNumberFormats(), nFormatKey);
+ sal_Int16 nKeyType = ::comphelper::getNumberFormatType(xFormatter->getNumberFormatsSupplier()->getNumberFormats(), nFormatKey);
while (!xListCursor->isAfterLast() && i++ < SHRT_MAX) // max anzahl eintraege
{
- aStr = ::utl::DBTypeConversion::getValue(xDataField,
+ aStr = ::dbtools::DBTypeConversion::getValue(xDataField,
xFormatter,
aNullDate,
nFormatKey,
@@ -2981,7 +2973,7 @@ void SAL_CALL FmXListBoxCell::addItem(const ::rtl::OUString& aItem, sal_Int16 nP
}
//------------------------------------------------------------------
-void SAL_CALL FmXListBoxCell::addItems(const ::utl::StringSequence& aItems, sal_Int16 nPos) throw( ::com::sun::star::uno::RuntimeException )
+void SAL_CALL FmXListBoxCell::addItems(const ::comphelper::StringSequence& aItems, sal_Int16 nPos) throw( ::com::sun::star::uno::RuntimeException )
{
::osl::MutexGuard aGuard( m_aMutex );
if (m_pBox)
@@ -3024,15 +3016,15 @@ sal_Int16 SAL_CALL FmXListBoxCell::getItemCount() throw( ::com::sun::star::uno::
return aItem;
}
//------------------------------------------------------------------
-::utl::StringSequence SAL_CALL FmXListBoxCell::getItems() throw( ::com::sun::star::uno::RuntimeException )
+::comphelper::StringSequence SAL_CALL FmXListBoxCell::getItems() throw( ::com::sun::star::uno::RuntimeException )
{
::osl::MutexGuard aGuard( m_aMutex );
- ::utl::StringSequence aSeq;
+ ::comphelper::StringSequence aSeq;
if (m_pBox)
{
sal_uInt16 nEntries = m_pBox ->GetEntryCount();
- aSeq = ::utl::StringSequence( nEntries );
+ aSeq = ::comphelper::StringSequence( nEntries );
for ( sal_uInt16 n = nEntries; n; )
{
--n;
@@ -3086,17 +3078,17 @@ sal_Int16 SAL_CALL FmXListBoxCell::getSelectedItemPos() throw( ::com::sun::star:
}
//------------------------------------------------------------------
-::utl::StringSequence SAL_CALL FmXListBoxCell::getSelectedItems() throw( ::com::sun::star::uno::RuntimeException )
+::comphelper::StringSequence SAL_CALL FmXListBoxCell::getSelectedItems() throw( ::com::sun::star::uno::RuntimeException )
{
::osl::MutexGuard aGuard( m_aMutex );
- ::utl::StringSequence aSeq;
+ ::comphelper::StringSequence aSeq;
if (m_pBox)
{
UpdateFromColumn();
sal_uInt16 nSelEntries = m_pBox->GetSelectEntryCount();
- aSeq = ::utl::StringSequence( nSelEntries );
+ aSeq = ::comphelper::StringSequence( nSelEntries );
for ( sal_uInt16 n = 0; n < nSelEntries; n++ )
aSeq.getArray()[n] = m_pBox->GetSelectEntry( n );
}
diff --git a/svx/source/fmcomp/gridcols.cxx b/svx/source/fmcomp/gridcols.cxx
index c14172e02a90..e08e91772f63 100644
--- a/svx/source/fmcomp/gridcols.cxx
+++ b/svx/source/fmcomp/gridcols.cxx
@@ -2,9 +2,9 @@
*
* $RCSfile: gridcols.cxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 17:01:16 $
+ * last change: $Author: fs $ $Date: 2000-10-20 14:13:45 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -67,8 +67,8 @@
#include <tools/debug.hxx>
#endif
-#ifndef _UTL_TYPES_HXX_
-#include <unotools/types.hxx>
+#ifndef _COMPHELPER_TYPES_HXX_
+#include <comphelper/types.hxx>
#endif
#ifndef _SVX_FMSERVS_HXX
@@ -91,9 +91,9 @@ IMPLEMENT_CONSTASCII_USTRING(FM_COL_LISTBOX, "ListBox");
IMPLEMENT_CONSTASCII_USTRING(FM_COL_FORMATTEDFIELD, "FormattedField");
//------------------------------------------------------------------------------
-const ::utl::StringSequence& getColumnTypes()
+const ::comphelper::StringSequence& getColumnTypes()
{
- static ::utl::StringSequence aColumnTypes(10);
+ static ::comphelper::StringSequence aColumnTypes(10);
if (!aColumnTypes.getConstArray()[0].getLength())
{
::rtl::OUString* pNames = aColumnTypes.getArray();
@@ -144,7 +144,7 @@ sal_Int32 getColumnTypeByModelName(const ::rtl::OUString& aModelName)
? aModelName.copy(aModelPrefix.len())
: aModelName.copy(aCompatibleModelPrefix.len());
- const ::utl::StringSequence& rColumnTypes = getColumnTypes();
+ const ::comphelper::StringSequence& rColumnTypes = getColumnTypes();
#if SUPD>583
nTypeId = findPos(aColumnType, rColumnTypes);
#else
diff --git a/svx/source/inc/fmcontr.hxx b/svx/source/inc/fmcontr.hxx
index a2a394843988..c32ab4774bb3 100644
--- a/svx/source/inc/fmcontr.hxx
+++ b/svx/source/inc/fmcontr.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: fmcontr.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 17:01:19 $
+ * last change: $Author: fs $ $Date: 2000-10-20 14:12:06 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -61,7 +61,9 @@
#ifndef _SVX_FMCONTR_HXX
#define _SVX_FMCONTR_HXX
-#include <unotools/stl_types.hxx>
+#ifndef _COMPHELPER_STLTYPES_HXX_
+#include <comphelper/stl_types.hxx>
+#endif
#ifndef _COM_SUN_STAR_FORM_XFORMCOMPONENT_HPP_
#include <com/sun/star/form/XFormComponent.hpp>
@@ -103,7 +105,7 @@
#include <com/sun/star/lang/EventObject.hpp>
#endif
-typedef ::std::hash_multimap< ::rtl::OUString, ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface > , ::utl::UStringHash, ::utl::UStringEqual> OInterfaceMap;
+typedef ::std::hash_multimap< ::rtl::OUString, ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface > , ::comphelper::UStringHash, ::comphelper::UStringEqual> OInterfaceMap;
DECLARE_STL_VECTOR(::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface > > ,InterfaceArray);
diff --git a/svx/source/inc/fmctrler.hxx b/svx/source/inc/fmctrler.hxx
index d5396056b624..ec72e22d80a8 100644
--- a/svx/source/inc/fmctrler.hxx
+++ b/svx/source/inc/fmctrler.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: fmctrler.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 17:01:19 $
+ * last change: $Author: fs $ $Date: 2000-10-20 14:12:06 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -61,8 +61,8 @@
#ifndef _SVX_FMCTRLER_HXX
#define _SVX_FMCTRLER_HXX
-#ifndef _UTL_STLTYPES_HXX_
-#include <unotools/stl_types.hxx>
+#ifndef _COMPHELPER_STLTYPES_HXX_
+#include <comphelper/stl_types.hxx>
#endif
#ifndef _COM_SUN_STAR_SDB_XSQLERRORBROADCASTER_HPP_
#include <com/sun/star/sdb/XSQLErrorBroadcaster.hpp>
@@ -230,8 +230,8 @@
#ifndef _FM_IMPLEMENTATION_IDS_HXX_
#include <fmimplids.hxx>
#endif
-#ifndef _UNOTOOLS_PROPERTY_ARRAY_HELPER_HXX_
-#include <unotools/proparrhlp.hxx>
+#ifndef _COMPHELPER_PROPERTY_ARRAY_HELPER_HXX_
+#include <comphelper/proparrhlp.hxx>
#endif
#ifndef _TOOLS_DEBUG_HXX
#include <tools/debug.hxx>
@@ -286,7 +286,7 @@ class FmXFormController :public ::cppu::OComponentHelper
,public ::com::sun::star::form::XResetListener
,public ::com::sun::star::lang::XUnoTunnel
,public FmDispatchInterceptor
- ,public ::utl::OAggregationArrayUsageHelper< FmXFormController>
+ ,public ::comphelper::OAggregationArrayUsageHelper< FmXFormController>
{
friend class FmXPageViewWinRec;
@@ -510,7 +510,7 @@ public:
// method for registration
static ::com::sun::star::uno::Sequence< ::rtl::OUString > static_getSupportedServiceNames(void);
- // utl::OPropertyArrayUsageHelper
+ // comphelper::OPropertyArrayUsageHelper
virtual void fillProperties(
::com::sun::star::uno::Sequence< ::com::sun::star::beans::Property >& /* [out] */ _rProps,
::com::sun::star::uno::Sequence< ::com::sun::star::beans::Property >& /* [out] */ _rAggregateProps
diff --git a/svx/source/inc/fmexch.hxx b/svx/source/inc/fmexch.hxx
index d8ce356ebdd3..0a259a28f3c8 100644
--- a/svx/source/inc/fmexch.hxx
+++ b/svx/source/inc/fmexch.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: fmexch.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 17:01:19 $
+ * last change: $Author: fs $ $Date: 2000-10-20 14:12:06 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -61,7 +61,9 @@
#ifndef _SVX_FMEXCH_HXX
#define _SVX_FMEXCH_HXX
-#include <unotools/stl_types.hxx>
+#ifndef _COMPHELPER_STLTYPES_HXX_
+#include <comphelper/stl_types.hxx>
+#endif
#ifndef _SOT_DTRANS_HXX //autogen
#include <sot/dtrans.hxx>
diff --git a/svx/source/inc/fmitems.hxx b/svx/source/inc/fmitems.hxx
index 4fa1ae07e09b..12b822f38b33 100644
--- a/svx/source/inc/fmitems.hxx
+++ b/svx/source/inc/fmitems.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: fmitems.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 17:01:19 $
+ * last change: $Author: fs $ $Date: 2000-10-20 14:12:06 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -66,7 +66,9 @@
#include <svtools/poolitem.hxx>
#endif
-#include <unotools/uno3.hxx>
+#ifndef _COMPHELPER_UNO3_HXX_
+#include <comphelper/uno3.hxx>
+#endif
// FORWARD_DECLARE_INTERFACE(awt,XControlContainer)
FORWARD_DECLARE_INTERFACE(uno,Any)
// class ::com::sun::star::uno::Any;
diff --git a/svx/source/inc/fmpgeimp.hxx b/svx/source/inc/fmpgeimp.hxx
index ac547590e97d..e792488d9931 100644
--- a/svx/source/inc/fmpgeimp.hxx
+++ b/svx/source/inc/fmpgeimp.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: fmpgeimp.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 17:01:19 $
+ * last change: $Author: fs $ $Date: 2000-10-20 14:12:06 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -86,8 +86,8 @@
#include <tools/list.hxx>
#endif
-#ifndef _UTL_UNO3_HXX_
-#include <unotools/uno3.hxx>
+#ifndef _COMPHELPER_UNO3_HXX_
+#include <comphelper/uno3.hxx>
#endif
class SvStream;
diff --git a/svx/source/inc/fmshimp.hxx b/svx/source/inc/fmshimp.hxx
index d9fa94a00175..a68af25fbdb4 100644
--- a/svx/source/inc/fmshimp.hxx
+++ b/svx/source/inc/fmshimp.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: fmshimp.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 17:01:19 $
+ * last change: $Author: fs $ $Date: 2000-10-20 14:12:06 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -184,11 +184,11 @@
#ifndef _CPPUHELPER_COMPONENT_HXX_
#include <cppuhelper/component.hxx>
#endif
-#ifndef _UTL_STLTYPES_HXX_
-#include "unotools/stl_types.hxx"
+#ifndef _COMPHELPER_STLTYPES_HXX_
+#include <comphelper/stl_types.hxx>
#endif
-#ifndef _UTL_CONTAINER_HXX_
-#include "unotools/container.hxx"
+#ifndef _COMPHELPER_CONTAINER_HXX_
+#include <comphelper/container.hxx>
#endif
#ifndef _FM_IMPLEMENTATION_IDS_HXX_
#include "fmimplids.hxx"
@@ -246,10 +246,10 @@ protected:
//==============================================================================
// a class iterating through all fields of a form which are bound to a field
// sub forms are ignored, grid columns (where the grid is a direct child of the form) are included
-class FmXBoundFormFieldIterator : public ::utl::IndexAccessIterator
+class FmXBoundFormFieldIterator : public ::comphelper::IndexAccessIterator
{
public:
- FmXBoundFormFieldIterator(const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface>& _rStartingPoint) : ::utl::IndexAccessIterator(_rStartingPoint) { }
+ FmXBoundFormFieldIterator(const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface>& _rStartingPoint) : ::comphelper::IndexAccessIterator(_rStartingPoint) { }
protected:
virtual sal_Bool ShouldHandleElement(const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface>& _rElement);
@@ -638,7 +638,7 @@ inline sal_Bool FmXFormShell::IsSelectionUpdatePending()
// = der Teil mit dem Container-Test fuer dieses Objekt.
// =
-class SearchableControlIterator : public ::utl::IndexAccessIterator
+class SearchableControlIterator : public ::comphelper::IndexAccessIterator
{
::rtl::OUString m_sCurrentValue;
// der aktuelle Wert der ControlSource-::com::sun::star::beans::Property
diff --git a/svx/source/inc/fmsrcimp.hxx b/svx/source/inc/fmsrcimp.hxx
index cc9330f8b860..19bc07354248 100644
--- a/svx/source/inc/fmsrcimp.hxx
+++ b/svx/source/inc/fmsrcimp.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: fmsrcimp.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 17:01:19 $
+ * last change: $Author: fs $ $Date: 2000-10-20 14:12:06 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -94,7 +94,9 @@
#include <com/sun/star/util/XNumberFormatter.hpp>
#endif
-#include <unotools/stl_types.hxx>
+#ifndef _COMPHELPER_STLTYPES_HXX_
+#include <comphelper/stl_types.hxx>
+#endif
#include <cppuhelper/implbase1.hxx>
// ===================================================================================================
diff --git a/svx/source/inc/fmtools.hxx b/svx/source/inc/fmtools.hxx
index 504034b9354d..26364d841357 100644
--- a/svx/source/inc/fmtools.hxx
+++ b/svx/source/inc/fmtools.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: fmtools.hxx,v $
*
- * $Revision: 1.2 $
+ * $Revision: 1.3 $
*
- * last change: $Author: oj $ $Date: 2000-09-22 09:41:35 $
+ * last change: $Author: fs $ $Date: 2000-10-20 14:12:06 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -220,8 +220,8 @@
#ifndef _CPPUHELPER_INTERFACECONTAINER_H_
#include <cppuhelper/interfacecontainer.h>
#endif
-#ifndef _UTL_UNO3_HXX_
-#include <unotools/uno3.hxx>
+#ifndef _COMPHELPER_UNO3_HXX_
+#include <comphelper/uno3.hxx>
#endif
#ifndef _CPPUHELPER_IMPLBASE1_HXX_
#include <cppuhelper/implbase1.hxx>
diff --git a/svx/source/inc/fmundo.hxx b/svx/source/inc/fmundo.hxx
index f59eccd38707..84fde3ffd427 100644
--- a/svx/source/inc/fmundo.hxx
+++ b/svx/source/inc/fmundo.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: fmundo.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 17:01:19 $
+ * last change: $Author: fs $ $Date: 2000-10-20 14:12:06 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -111,7 +111,9 @@
#include "svdouno.hxx"
#endif
-#include <unotools/uno3.hxx>
+#ifndef _COMPHELPER_UNO3_HXX_
+#include <comphelper/uno3.hxx>
+#endif
class FmFormModel;
class FmFormObj;
diff --git a/svx/source/inc/fmvwimp.hxx b/svx/source/inc/fmvwimp.hxx
index a8b1c6c4000d..771257ca90e8 100644
--- a/svx/source/inc/fmvwimp.hxx
+++ b/svx/source/inc/fmvwimp.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: fmvwimp.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 17:01:20 $
+ * last change: $Author: fs $ $Date: 2000-10-20 14:12:06 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -61,7 +61,9 @@
#ifndef _SVX_FMVWIMP_HXX
#define _SVX_FMVWIMP_HXX
-#include <unotools/stl_types.hxx>
+#ifndef _COMPHELPER_STLTYPES_HXX_
+#include <comphelper/stl_types.hxx>
+#endif
#ifndef _COM_SUN_STAR_FORM_XFORM_HPP_
@@ -96,8 +98,8 @@
#ifndef _CPPUHELPER_IMPLBASE2_HXX_
#include <cppuhelper/implbase2.hxx>
#endif
-#ifndef _UTL_UNO3_HXX_
-#include <unotools/uno3.hxx>
+#ifndef _COMPHELPER_UNO3_HXX_
+#include <comphelper/uno3.hxx>
#endif
class SdrPageViewWinRec;
diff --git a/svx/source/inc/gridcell.hxx b/svx/source/inc/gridcell.hxx
index cc64a5eb8e44..7b79bcaa565f 100644
--- a/svx/source/inc/gridcell.hxx
+++ b/svx/source/inc/gridcell.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: gridcell.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 17:01:20 $
+ * last change: $Author: fs $ $Date: 2000-10-20 14:12:06 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -105,8 +105,8 @@
#include <com/sun/star/lang/XUnoTunnel.hpp>
#endif
-#ifndef _UNOTOOLS_PROPERTY_MULTIPLEX_HXX_
-#include <unotools/propmultiplex.hxx>
+#ifndef _COMPHELPER_PROPERTY_MULTIPLEX_HXX_
+#include <comphelper/propmultiplex.hxx>
#endif
class DbCellControl;
@@ -296,10 +296,10 @@ protected:
};
//==================================================================
-class DbFormattedField : public DbCellControl, public ::utl::OPropertyChangeListener
+class DbFormattedField : public DbCellControl, public ::comphelper::OPropertyChangeListener
{
protected:
- ::utl::OPropertyChangeMultiplexer* m_pFormatListener;
+ ::comphelper::OPropertyChangeMultiplexer* m_pFormatListener;
::com::sun::star::uno::Reference< ::com::sun::star::util::XNumberFormatsSupplier > m_xSupplier;
sal_Int16 m_nKeyType;
@@ -350,7 +350,7 @@ public:
//==================================================================
class DbComboBox :public DbCellControl
- ,public ::utl::OPropertyChangeListener
+ ,public ::comphelper::OPropertyChangeListener
{
sal_Int16 m_nKeyType;
::osl::Mutex m_aDummy;
@@ -373,7 +373,7 @@ public:
//==================================================================
class DbListBox : public DbCellControl,
- public ::utl::OPropertyChangeListener
+ public ::comphelper::OPropertyChangeListener
{
sal_Bool m_bBound : 1;
::com::sun::star::uno::Sequence< ::rtl::OUString > m_aValueList;
diff --git a/svx/source/inc/tabwin.hxx b/svx/source/inc/tabwin.hxx
index b376e40f832b..ca1d8bc13cda 100644
--- a/svx/source/inc/tabwin.hxx
+++ b/svx/source/inc/tabwin.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: tabwin.hxx,v $
*
- * $Revision: 1.1.1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: hr $ $Date: 2000-09-18 17:01:20 $
+ * last change: $Author: fs $ $Date: 2000-10-20 14:12:06 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -89,7 +89,9 @@
//#include "fmtools.hxx"
//#endif
-#include <unotools/propmultiplex.hxx>
+#ifndef _COMPHELPER_PROPERTY_MULTIPLEX_HXX_
+#include <comphelper/propmultiplex.hxx>
+#endif
//==================================================================
class FmFieldWin;
@@ -123,7 +125,7 @@ public:
//========================================================================
class FmFieldWin : public SfxFloatingWindow,
public SfxControllerItem,
- public ::utl::OPropertyChangeListener
+ public ::comphelper::OPropertyChangeListener
{
::osl::Mutex m_aMutex;
FmFieldWinListBox* pListBox;
@@ -132,7 +134,7 @@ class FmFieldWin : public SfxFloatingWindow,
m_aObjectName;
sal_Int32 m_nObjectType;
- ::utl::OPropertyChangeMultiplexer* m_pChangeListener;
+ ::comphelper::OPropertyChangeMultiplexer* m_pChangeListener;
public:
FmFieldWin(SfxBindings *pBindings,
diff --git a/svx/source/fmcomp/gridctrl.cxx b/svx/source/fmcomp/gridctrl.cxx
index a1fcd26fc8d1..af573f24f630 100644
--- a/svx/source/fmcomp/gridctrl.cxx
+++ b/svx/source/fmcomp/gridctrl.cxx
@@ -2,9 +2,9 @@
*
* $RCSfile: gridctrl.cxx,v $
*
- * $Revision: 1.3 $
+ * $Revision: 1.4 $
*
- * last change: $Author: oj $ $Date: 2000-09-29 08:25:14 $
+ * last change: $Author: fs $ $Date: 2000-10-20 14:13:45 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -167,23 +167,28 @@
String INVALIDTEXT = String::CreateFromAscii("###");
String OBJECTTEXT = String::CreateFromAscii("<OBJECT>");
-#ifndef _UTL_STLTYPES_HXX_
-#include <unotools/stl_types.hxx>
+#ifndef _COMPHELPER_STLTYPES_HXX_
+#include <comphelper/stl_types.hxx>
#endif
-#ifndef _UTL_UNO3_DB_TOOLS_HXX_
-#include <unotools/dbtools.hxx>
+#ifndef _CONNECTIVITY_DBTOOLS_HXX_
+#include <connectivity/dbtools.hxx>
#endif
-#ifndef _UNOTOOLS_DATETIME_HXX_
-#include <unotools/datetime.hxx>
+#ifndef _DBHELPER_DBCONVERSION_HXX_
+#include <connectivity/dbconversion.hxx>
#endif
-#ifndef _UTL_PROPERTY_HXX_
-#include <unotools/property.hxx>
+#ifndef _COMPHELPER_DATETIME_HXX_
+#include <comphelper/datetime.hxx>
+#endif
+#ifndef _COMPHELPER_PROPERTY_HXX_
+#include <comphelper/property.hxx>
#endif
#ifndef _TRACE_HXX_
#include "trace.hxx"
#endif
+using namespace dbtools;
+
#define ROWSTATUS(row) !row.Is() ? "NULL" : row->GetStatus() == GRS_CLEAN ? "CLEAN" : row->GetStatus() == GRS_MODIFIED ? "MODIFIED" : row->GetStatus() == GRS_DELETED ? "DELETED" : "INVALID"
//==============================================================================
@@ -194,11 +199,11 @@ DECLARE_STL_MAP(sal_uInt16, GridFieldValueListener*, ::std::less<sal_uInt16>, Co
//==============================================================================
DBG_NAME(GridFieldValueListener);
-class GridFieldValueListener : protected ::utl::OPropertyChangeListener
+class GridFieldValueListener : protected ::comphelper::OPropertyChangeListener
{
osl::Mutex m_aMutex;
DbGridControl& m_rParent;
- ::utl::OPropertyChangeMultiplexer* m_pRealListener;
+ ::comphelper::OPropertyChangeMultiplexer* m_pRealListener;
sal_uInt16 m_nId;
sal_Int16 m_nSuspended;
sal_Bool m_bDisposed : 1;
@@ -226,7 +231,7 @@ GridFieldValueListener::GridFieldValueListener(DbGridControl& _rParent, const ::
DBG_CTOR(GridFieldValueListener, NULL);
if (_rField.is())
{
- m_pRealListener = new ::utl::OPropertyChangeMultiplexer(this, _rField);
+ m_pRealListener = new ::comphelper::OPropertyChangeMultiplexer(this, _rField);
m_pRealListener->addProperty(FM_PROP_VALUE);
m_pRealListener->acquire();
}
@@ -333,11 +338,11 @@ static sal_uInt16 ControlMap[] =
//------------------------------------------------------------------------------
sal_Bool CompareBookmark(const ::com::sun::star::uno::Any& aLeft, const ::com::sun::star::uno::Any& aRight)
{
- return ::utl::compare(aLeft, aRight);
+ return ::comphelper::compare(aLeft, aRight);
}
//==============================================================================
-class FmXGridSourcePropListener : public ::utl::OPropertyChangeListener
+class FmXGridSourcePropListener : public ::comphelper::OPropertyChangeListener
{
DbGridControl* m_pParent;
@@ -875,10 +880,10 @@ DbGridRow::DbGridRow(CursorWrapper* pCur, sal_Bool bPaintCursor)
::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > xSet(*pCur,::com::sun::star::uno::UNO_QUERY);
if (xSet.is())
{
- m_bIsNew = ::utl::getBOOL(xSet->getPropertyValue(FM_PROP_ISNEW));
+ m_bIsNew = ::comphelper::getBOOL(xSet->getPropertyValue(FM_PROP_ISNEW));
if (!m_bIsNew && (pCur->isAfterLast() || pCur->isBeforeFirst()))
m_eStatus = GRS_INVALID;
- else if (::utl::getBOOL(xSet->getPropertyValue(FM_PROP_ISMODIFIED)))
+ else if (::comphelper::getBOOL(xSet->getPropertyValue(FM_PROP_ISMODIFIED)))
m_eStatus = GRS_MODIFIED;
else
m_eStatus = GRS_CLEAN;
@@ -922,9 +927,9 @@ void DbGridRow::SetState(CursorWrapper* pCur, sal_Bool bPaintCursor)
::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > xSet(*pCur, ::com::sun::star::uno::UNO_QUERY);
DBG_ASSERT(xSet.is(), "DbGridRow::SetState : invalid cursor !");
- if (::utl::getBOOL(xSet->getPropertyValue(FM_PROP_ISMODIFIED)))
+ if (::comphelper::getBOOL(xSet->getPropertyValue(FM_PROP_ISMODIFIED)))
m_eStatus = GRS_MODIFIED;
- m_bIsNew = ::utl::getBOOL(xSet->getPropertyValue(FM_PROP_ISNEW));
+ m_bIsNew = ::comphelper::getBOOL(xSet->getPropertyValue(FM_PROP_ISNEW));
}
else
m_bIsNew = sal_False;
@@ -963,7 +968,7 @@ DbGridControl::DbGridControl(
,m_bSynchDisplay(sal_True)
,m_bForceROController(sal_False)
,m_bHandle(sal_False)
- ,m_aNullDate(STANDARD_DATE)
+ ,m_aNullDate(DBTypeConversion::STANDARD_DB_DATE)
,m_nAsynAdjustEvent(0)
,m_pDataSourcePropMultiplexer(NULL)
,m_pDataSourcePropListener(NULL)
@@ -998,7 +1003,7 @@ DbGridControl::DbGridControl(
,m_bSynchDisplay(sal_True)
,m_bForceROController(sal_False)
,m_bHandle(sal_False)
- ,m_aNullDate(STANDARD_DATE)
+ ,m_aNullDate(DBTypeConversion::STANDARD_DB_DATE)
,m_pDataSourcePropMultiplexer(NULL)
,m_pDataSourcePropListener(NULL)
,m_pFieldListeners(NULL)
@@ -1453,7 +1458,7 @@ void DbGridControl::setDataSource(const ::com::sun::star::uno::Reference< ::com:
// get a new formatter and data cursor
m_xFormatter = NULL;
- ::com::sun::star::uno::Reference< ::com::sun::star::util::XNumberFormatsSupplier > xSupplier = ::utl::getNumberFormats(::utl::getConnection(_xCursor), sal_True);
+ ::com::sun::star::uno::Reference< ::com::sun::star::util::XNumberFormatsSupplier > xSupplier = ::dbtools::getNumberFormats(::dbtools::getConnection(_xCursor), sal_True);
if (xSupplier.is() && m_xServiceFactory.is())
{
m_xFormatter = ::com::sun::star::uno::Reference< ::com::sun::star::util::XNumberFormatter >(
@@ -1466,11 +1471,9 @@ void DbGridControl::setDataSource(const ::com::sun::star::uno::Reference< ::com:
// retrieve the datebase of the Numberformatter
try
{
- ::com::sun::star::util::Date aUnoDate;
- xSupplier->getNumberFormatSettings()->getPropertyValue(rtl::OUString::createFromAscii("NullDate")) >>= aUnoDate;
- ::utl::typeConvert(aUnoDate, m_aNullDate);
+ xSupplier->getNumberFormatSettings()->getPropertyValue(rtl::OUString::createFromAscii("NullDate")) >>= m_aNullDate;
}
- catch(...)
+ catch(staruno::Exception&)
{
}
}
@@ -1493,13 +1496,13 @@ void DbGridControl::setDataSource(const ::com::sun::star::uno::Reference< ::com:
// property listening on the data source
// (Normally one class would be sufficient : the multiplexer which could forward the property change to us.
// But for that we would have been derived from ::utl::OPropertyChangeListener, which isn't exported.
// So we introduce a second class, which is a ::utl::OPropertyChangeListener (in the implementation file we know this class)
// and forwards the property changes to a our special method "DataSourcePropertyChanged".)
if (m_pDataCursor)
{
m_pDataSourcePropListener = new FmXGridSourcePropListener(this);
- m_pDataSourcePropMultiplexer = new ::utl::OPropertyChangeMultiplexer(m_pDataSourcePropListener, ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > (*m_pDataCursor, ::com::sun::star::uno::UNO_QUERY));
+ m_pDataSourcePropMultiplexer = new ::comphelper::OPropertyChangeMultiplexer(m_pDataSourcePropListener, ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > (*m_pDataCursor, ::com::sun::star::uno::UNO_QUERY));
m_pDataSourcePropMultiplexer->acquire();
m_pDataSourcePropMultiplexer->addProperty(FM_PROP_ISMODIFIED);
m_pDataSourcePropMultiplexer->addProperty(FM_PROP_ISNEW);
@@ -1564,7 +1567,7 @@ void DbGridControl::setDataSource(const ::com::sun::star::uno::Reference< ::com:
{
::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > xSet(*m_pDataCursor, ::com::sun::star::uno::UNO_QUERY);
xSet->getPropertyValue(FM_PROP_ROWCOUNT) >>= nRecordCount;
- m_bRecordCountFinal = ::utl::getBOOL(xSet->getPropertyValue(FM_PROP_ROWCOUNTFINAL));
+ m_bRecordCountFinal = ::comphelper::getBOOL(xSet->getPropertyValue(FM_PROP_ROWCOUNTFINAL));
// insert the currently known rows
// and one row if we are able to insert rows
@@ -1918,7 +1921,7 @@ void DbGridControl::AdjustRows()
sal_Int32 nRecordCount;
xSet->getPropertyValue(FM_PROP_ROWCOUNT) >>= nRecordCount;
if (!m_bRecordCountFinal)
- m_bRecordCountFinal = ::utl::getBOOL(xSet->getPropertyValue(FM_PROP_ROWCOUNTFINAL));
+ m_bRecordCountFinal = ::comphelper::getBOOL(xSet->getPropertyValue(FM_PROP_ROWCOUNTFINAL));
// hat sich die aktuelle Anzahl Rows veraendert
// hierbei muss auch beruecksichtigt werden,
@@ -2049,7 +2052,7 @@ sal_Bool DbGridControl::SetCurrent(long nNewRow, sal_Bool bForceInsertIfNewRow)
// we need to insert the if the current row isn't the insert row or if the
// cursor triggered the move by itselt and we need a reinitialization of the row
::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > xCursorProps(*m_pDataCursor, ::com::sun::star::uno::UNO_QUERY);
- if (bForceInsertIfNewRow || !::utl::getBOOL(xCursorProps->getPropertyValue(FM_PROP_ISNEW)))
+ if (bForceInsertIfNewRow || !::comphelper::getBOOL(xCursorProps->getPropertyValue(FM_PROP_ISNEW)))
{
::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XResultSetUpdate > xUpdateCursor(*m_pDataCursor, ::com::sun::star::uno::UNO_QUERY);
xUpdateCursor->moveToInsertRow();
@@ -2198,7 +2201,7 @@ void DbGridControl::AdjustDataSource(sal_Bool bFull)
// may not be correct
else if (m_xCurrentRow.Is() && !m_xCurrentRow->IsNew() &&
CompareBookmark(m_xCurrentRow->GetBookmark(), m_pDataCursor->getBookmark()) &&
- !::utl::getBOOL(::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > (*m_pDataCursor, ::com::sun::star::uno::UNO_QUERY)->getPropertyValue(FM_PROP_ISNEW)))
+ !::comphelper::getBOOL(::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > (*m_pDataCursor, ::com::sun::star::uno::UNO_QUERY)->getPropertyValue(FM_PROP_ISNEW)))
{
// Position ist ein und dieselbe
// Status uebernehmen, neuzeichnen fertig
@@ -2257,7 +2260,7 @@ sal_Int32 DbGridControl::AlignSeekCursor()
::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > xSet(*m_pDataCursor, ::com::sun::star::uno::UNO_QUERY);
// jetzt den seekcursor an den DatenCursor angleichen
- if (::utl::getBOOL(xSet->getPropertyValue(FM_PROP_ISNEW)))
+ if (::comphelper::getBOOL(xSet->getPropertyValue(FM_PROP_ISNEW)))
m_nSeekPos = GetRowCount() - 1;
else
{
@@ -2668,14 +2671,14 @@ void DbGridControl::DataSourcePropertyChanged(const ::com::sun::star::beans::Pro
::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > xSource(evt.Source, ::com::sun::star::uno::UNO_QUERY);
sal_Bool bIsNew = sal_False;
if (xSource.is())
- bIsNew = ::utl::getBOOL(xSource->getPropertyValue(FM_PROP_ISNEW));
+ bIsNew = ::comphelper::getBOOL(xSource->getPropertyValue(FM_PROP_ISNEW));
if (bIsNew)
{
- DBG_ASSERT(::utl::getBOOL(xSource->getPropertyValue(FM_PROP_ROWCOUNTFINAL)), "DbGridControl::DataSourcePropertyChanged : somebody moved the form to a new record before the row count was final !");
+ DBG_ASSERT(::comphelper::getBOOL(xSource->getPropertyValue(FM_PROP_ROWCOUNTFINAL)), "DbGridControl::DataSourcePropertyChanged : somebody moved the form to a new record before the row count was final !");
sal_Int32 nRecordCount;
xSource->getPropertyValue(FM_PROP_ROWCOUNT) >>= nRecordCount;
- if (::utl::getBOOL(evt.NewValue))
+ if (::comphelper::getBOOL(evt.NewValue))
{ // modified state changed from sal_False to sal_True and we're on a insert row
// -> we've to add a new grid row
if ((nRecordCount == GetRowCount() - 1) && m_xCurrentRow->IsNew())
@@ -2700,7 +2703,7 @@ void DbGridControl::DataSourcePropertyChanged(const ::com::sun::star::beans::Pro
}
if (m_xCurrentRow.Is())
{
- m_xCurrentRow->SetStatus(::utl::getBOOL(evt.NewValue) ? GRS_MODIFIED : GRS_CLEAN);
+ m_xCurrentRow->SetStatus(::comphelper::getBOOL(evt.NewValue) ? GRS_MODIFIED : GRS_CLEAN);
TRACE_RANGE_MESSAGE1("modified flag changed, new state : %s", ROWSTATUS(m_xCurrentRow));
}
}
@@ -2867,9 +2870,9 @@ DbCellController* DbGridControl::GetController(long nRow, sal_uInt16 nColumnId)
pReturn = &pColumn->GetController();
else
{
- if (::utl::hasProperty(FM_PROP_ENABLED, pColumn->getModel()))
+ if (::comphelper::hasProperty(FM_PROP_ENABLED, pColumn->getModel()))
{
- if (!::utl::getBOOL(pColumn->getModel()->getPropertyValue(FM_PROP_ENABLED)))
+ if (!::comphelper::getBOOL(pColumn->getModel()->getPropertyValue(FM_PROP_ENABLED)))
return NULL;
}
@@ -3042,7 +3045,7 @@ void DbGridControl::resetCurrentRow()
// is the only possibility to determine the redundance of the row (resetCurrentRow is called when the
// "first insert row" is about to be cleaned, so of course the "second insert row" is redundant now)
::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > xDataSource(*getDataSource(), ::com::sun::star::uno::UNO_QUERY);
- if (xDataSource.is() && !::utl::getBOOL(xDataSource->getPropertyValue(FM_PROP_ISMODIFIED)))
+ if (xDataSource.is() && !::comphelper::getBOOL(xDataSource->getPropertyValue(FM_PROP_ISMODIFIED)))
{
// are we on a new row currently ?
if (m_xCurrentRow->IsNew())
@@ -1493,13 +1496,13 @@ void DbGridControl::setDataSource(const ::com::sun::star::uno::Reference< ::com:
// property listening on the data source
// (Normally one class would be sufficient : the multiplexer which could forward the property change to us.
- // But for that we would have been derived from ::utl::OPropertyChangeListener, which isn't exported.
- // So we introduce a second class, which is a ::utl::OPropertyChangeListener (in the implementation file we know this class)
+ // But for that we would have been derived from ::comphelper::OPropertyChangeListener, which isn't exported.
+ // So we introduce a second class, which is a ::comphelper::OPropertyChangeListener (in the implementation file we know this class)
// and forwards the property changes to a our special method "DataSourcePropertyChanged".)
if (m_pDataCursor)